@@ -94,6 +94,12 @@ Attack.prototype.Schema =
 			"<MaxRange>24.0</MaxRange>" +
 			"<MinRange>20.0</MinRange>" +
 		"</Charge>" +
+		"<Slaughter>" +
+			"<Hack>1000.0</Hack>" +
+			"<Pierce>0.0</Pierce>" +
+			"<Crush>0.0</Crush>" +
+			"<MaxRange>4.0</MaxRange>" +
+		"</Slaughter>" +
 	"</a:example>" +
 	"<optional>" +
 		"<element name='Melee'>" +
@@ -161,6 +167,19 @@ Attack.prototype.Schema =
 				restrictedClassesSchema +
 			"</interleave>" +
 		"</element>" +
+	"</optional>" +
+	"<optional>" +
+		"<element name='Slaughter' a:help='A special attack to kill domestic animals'>" +
+			"<interleave>" +
+				"<element name='Hack' a:help='Hack damage strength'><ref name='nonNegativeDecimal'/></element>" +
+				"<element name='Pierce' a:help='Pierce damage strength'><ref name='nonNegativeDecimal'/></element>" +
+				"<element name='Crush' a:help='Crush damage strength'><ref name='nonNegativeDecimal'/></element>" +
+				"<element name='MaxRange'><ref name='nonNegativeDecimal'/></element>" + // TODO: how do these work?
+				bonusesSchema +
+				preferredClassesSchema +
+				restrictedClassesSchema +
+			"</interleave>" +
+		"</element>" +
 	"</optional>";
 
 Attack.prototype.Init = function()
@@ -275,6 +294,10 @@ Attack.prototype.GetBestAttackAgainst = function(target)
 	const isAllowed = function (value, i, a) { return !attack.GetRestrictedClasses(value).some(isTargetClass); }
 	const isPreferred = function (value, i, a) { return attack.GetPreferredClasses(value).some(isTargetClass); }
 	const byPreference = function (a, b) { return (types.indexOf(a) + (isPreferred(a) ? types.length : 0) ) - (types.indexOf(b) + (isPreferred(b) ? types.length : 0) ); }
+	
+	// Always slaughter domestic animals instead of using a normal attack
+	if (isTargetClass("Domestic") && this.template.Slaughter) 
+		return "Slaughter";
 
 	return types.filter(isAllowed).sort(byPreference).pop();
 };
@@ -293,14 +316,10 @@ Attack.prototype.CompareEntitiesByPreference = function(a, b)
 Attack.prototype.GetTimers = function(type)
 {
 	var prepare = +(this.template[type].PrepareTime || 0);
+	prepare = ApplyTechModificationsToEntity("Attack/" + type + "/PrepareTime", prepare, this.entity);
+	
 	var repeat = +(this.template[type].RepeatTime || 1000);
-
-	var cmpTechMan = QueryOwnerInterface(this.entity, IID_TechnologyManager);
-	if (cmpTechMan)
-	{
-		prepare = cmpTechMan.ApplyModifications("Attack/" + type + "/PrepareTime", prepare, this.entity);
-		repeat = cmpTechMan.ApplyModifications("Attack/" + type + "/RepeatTime", repeat, this.entity);
-	}
+	repeat = ApplyTechModificationsToEntity("Attack/" + type + "/RepeatTime", repeat, this.entity);
 
 	return { "prepare": prepare, "repeat": repeat, "recharge": repeat - prepare };
 };
@@ -318,17 +337,11 @@ Attack.prototype.GetAttackStrengths = function(type)
 		splash = "/Splash";
 	}
 	
-	var cmpTechMan = QueryOwnerInterface(this.entity, IID_TechnologyManager);
 	var applyTechs = function(damageType)
 	{
-		var strength = +(template[damageType] || 0);
-		if (cmpTechMan)
-		{
-			// All causes caching problems so disable it for now.
-			//var allComponent = cmpTechMan.ApplyModifications("Attack/" + type + splash + "/All", strength, self.entity) - self.template[type][damageType];
-			strength = cmpTechMan.ApplyModifications("Attack/" + type + splash + "/" + damageType, strength, self.entity);
-		}
-		return strength;
+		// All causes caching problems so disable it for now.
+		//var allComponent = ApplyTechModificationsToEntity("Attack/" + type + splash + "/All", +(template[damageType] || 0), self.entity) - self.template[type][damageType];
+		return ApplyTechModificationsToEntity("Attack/" + type + splash + "/" + damageType, +(template[damageType] || 0), self.entity);
 	};
 	
 	return {
@@ -341,14 +354,10 @@ Attack.prototype.GetAttackStrengths = function(type)
 Attack.prototype.GetRange = function(type)
 {
 	var max = +this.template[type].MaxRange;
+	max = ApplyTechModificationsToEntity("Attack/" + type + "/MaxRange", max, this.entity);
+	
 	var min = +(this.template[type].MinRange || 0);
-
-	var cmpTechMan = QueryOwnerInterface(this.entity, IID_TechnologyManager);
-	if (cmpTechMan)
-	{
-		max = cmpTechMan.ApplyModifications("Attack/" + type + "/MaxRange", max, this.entity);
-		min = cmpTechMan.ApplyModifications("Attack/" + type + "/MinRange", min, this.entity);
-	}
+	min = ApplyTechModificationsToEntity("Attack/" + type + "/MinRange", min, this.entity);
 	
 	return { "max": max, "min": min };
 };
@@ -420,6 +429,7 @@ Attack.prototype.PerformAttack = function(type, target)
 		var gravity = 9.81; // this affects the shape of the curve; assume it's constant for now
 		
 		var spread = this.template.Ranged.Spread;
+		spread = ApplyTechModificationsToEntity("Attack/Ranged/Spread", spread, this.entity);
 		
 		//horizSpeed /= 2; gravity /= 2; // slow it down for testing
 		
@@ -689,7 +699,7 @@ Attack.prototype.CauseDamage = function(data)
 	}
 
 	Engine.PostMessage(data.target, MT_Attacked,
-		{ "attacker": this.entity, "target": data.target, "type": data.type });
+		{ "attacker": this.entity, "target": data.target, "type": data.type, "damage": -targetState.change });
 
 	PlaySound("attack_impact", this.entity);
 };
