@@ -49,7 +49,7 @@ GuiInterface.prototype.GetSimulationState = function(player)
 	for (var i = 0; i < n; ++i)
 	{
 		var playerEnt = cmpPlayerMan.GetPlayerByID(i);
-		var cmpPlayerBuildLimits = Engine.QueryInterface(playerEnt, IID_BuildLimits);
+		var cmpPlayerEntityLimits = Engine.QueryInterface(playerEnt, IID_EntityLimits);
 		var cmpPlayer = Engine.QueryInterface(playerEnt, IID_Player);
 		
 		// Work out what phase we are in
@@ -62,12 +62,14 @@ GuiInterface.prototype.GetSimulationState = function(player)
 		else if (cmpTechnologyManager.IsTechnologyResearched("phase_village"))
 			phase = "village";
 		
-		// store player ally/enemy data as arrays
+		// store player ally/neutral/enemy data as arrays
 		var allies = [];
+		var neutrals = [];
 		var enemies = [];
-		for (var j = 0; j <= n; ++j)
+		for (var j = 0; j < n; ++j)
 		{
 			allies[j] = cmpPlayer.IsAlly(j);
+			neutrals[j] = cmpPlayer.IsNeutral(j);
 			enemies[j] = cmpPlayer.IsEnemy(j);
 		}
 		var playerData = {
@@ -81,12 +83,19 @@ GuiInterface.prototype.GetSimulationState = function(player)
 			"trainingBlocked": cmpPlayer.IsTrainingBlocked(),
 			"state": cmpPlayer.GetState(),
 			"team": cmpPlayer.GetTeam(),
+			"teamsLocked": cmpPlayer.GetLockTeams(),
 			"phase": phase,
 			"isAlly": allies,
+			"isNeutral": neutrals,
 			"isEnemy": enemies,
-			"buildLimits": cmpPlayerBuildLimits.GetLimits(),
-			"buildCounts": cmpPlayerBuildLimits.GetCounts(),
-			"techModifications": cmpTechnologyManager.GetTechModifications()
+			"entityLimits": cmpPlayerEntityLimits.GetLimits(),
+			"entityCounts": cmpPlayerEntityLimits.GetCounts(),
+			"techModifications": cmpTechnologyManager.GetTechModifications(),
+			"researchQueued": cmpTechnologyManager.GetQueuedResearch(),
+			"researchStarted": cmpTechnologyManager.GetStartedResearch(),
+			"researchedTechs": cmpTechnologyManager.GetResearchedTechs(),
+			"classCounts": cmpTechnologyManager.GetClassCounts(),
+			"typeCountsByClass": cmpTechnologyManager.GetTypeCountsByClass()
 		};
 		ret.players.push(playerData);
 	}
@@ -165,7 +174,7 @@ GuiInterface.prototype.GetEntityState = function(player, ent)
 	var cmpHealth = Engine.QueryInterface(ent, IID_Health);
 	if (cmpHealth)
 	{
-		ret.hitpoints = cmpHealth.GetHitpoints();
+		ret.hitpoints = Math.ceil(cmpHealth.GetHitpoints());
 		ret.maxHitpoints = cmpHealth.GetMaxHitpoints();
 		ret.needsRepair = cmpHealth.IsRepairable() && (cmpHealth.GetHitpoints() < cmpHealth.GetMaxHitpoints());
 		ret.needsHeal = !cmpHealth.IsUnhealable();
@@ -176,6 +185,10 @@ GuiInterface.prototype.GetEntityState = function(player, ent)
 	{
 		var type = cmpAttack.GetBestAttack(); // TODO: how should we decide which attack to show? show all?
 		ret.attack = cmpAttack.GetAttackStrengths(type);
+		var range = cmpAttack.GetRange(type);
+		ret.attack.type = type;
+		ret.attack.minRange = range.min;
+		ret.attack.maxRange = range.max;
 	}
 
 	var cmpArmour = Engine.QueryInterface(ent, IID_DamageReceiver);
@@ -190,6 +203,15 @@ GuiInterface.prototype.GetEntityState = function(player, ent)
 		ret.buildEntities = cmpBuilder.GetEntitiesList();
 	}
 
+	var cmpPack = Engine.QueryInterface(ent, IID_Pack);
+	if (cmpPack)
+	{
+		ret.pack = {
+			"packed": cmpPack.IsPacked(),
+			"progress": cmpPack.GetProgress(),
+		};
+	}
+
 	var cmpProductionQueue = Engine.QueryInterface(ent, IID_ProductionQueue);
 	if (cmpProductionQueue)
 	{
@@ -239,7 +261,9 @@ GuiInterface.prototype.GetEntityState = function(player, ent)
 			"max": cmpResourceSupply.GetMaxAmount(),
 			"amount": cmpResourceSupply.GetCurrentAmount(),
 			"type": cmpResourceSupply.GetType(),
-			"killBeforeGather": cmpResourceSupply.GetKillBeforeGather()
+			"killBeforeGather": cmpResourceSupply.GetKillBeforeGather(),
+			"maxGatherers": cmpResourceSupply.GetMaxGatherers(),
+			"gatherers": cmpResourceSupply.GetGatherers()
 		};
 	}
 
@@ -348,9 +372,11 @@ GuiInterface.prototype.GetTemplateData = function(player, name)
 		for (var type in template.Attack)
 		{
 			ret.attack[type] = {
-				"hack": GetTechModifiedProperty(techMods, template, "Attack/"+type+"/Hack", +template.Attack[type].Hack || 0),
-				"pierce": GetTechModifiedProperty(techMods, template, "Attack/"+type+"/Pierce", +template.Attack[type].Pierce || 0),
-				"crush": GetTechModifiedProperty(techMods, template, "Attack/"+type+"/Crush", +template.Attack[type].Crush || 0),
+				"hack": GetTechModifiedProperty(techMods, template, "Attack/"+type+"/Hack", +(template.Attack[type].Hack || 0)),
+				"pierce": GetTechModifiedProperty(techMods, template, "Attack/"+type+"/Pierce", +(template.Attack[type].Pierce || 0)),
+				"crush": GetTechModifiedProperty(techMods, template, "Attack/"+type+"/Crush", +(template.Attack[type].Crush || 0)),
+				"minRange": GetTechModifiedProperty(techMods, template, "Attack/"+type+"/MinRange", +(template.Attack[type].MinRange || 0)),
+				"maxRange": GetTechModifiedProperty(techMods, template, "Attack/"+type+"/MaxRange", +template.Attack[type].MaxRange),
 			};
 		}
 	}
@@ -374,7 +400,14 @@ GuiInterface.prototype.GetTemplateData = function(player, name)
 			if (template.BuildRestrictions.Distance.MaxDistance) ret.buildRestrictions.distance.max = +template.BuildRestrictions.Distance.MaxDistance;
 		}
 	}
-	
+
+	if (template.TrainingRestrictions)
+	{
+		ret.trainingRestrictions = {
+			"category": template.TrainingRestrictions.Category,
+		};
+	}
+
 	if (template.Cost)
 	{
 		ret.cost = {};
@@ -384,6 +417,7 @@ GuiInterface.prototype.GetTemplateData = function(player, name)
 		if (template.Cost.Resources.metal) ret.cost.metal = GetTechModifiedProperty(techMods, template, "Cost/Resources/metal", +template.Cost.Resources.metal);
 		if (template.Cost.Population) ret.cost.population = GetTechModifiedProperty(techMods, template, "Cost/Population", +template.Cost.Population);
 		if (template.Cost.PopulationBonus) ret.cost.populationBonus = GetTechModifiedProperty(techMods, template, "Cost/PopulationBonus", +template.Cost.PopulationBonus);
+		if (template.Cost.BuildTime) ret.cost.time = GetTechModifiedProperty(techMods, template, "Cost/BuildTime", +template.Cost.BuildTime);
 	}
 	
 	if (template.Footprint)
@@ -427,10 +461,18 @@ GuiInterface.prototype.GetTemplateData = function(player, name)
 			ret.obstruction.shape.type = "cluster";
 		}
 	}
-	
+
+	if (template.Pack)
+	{
+		ret.pack = {
+			"state": template.Pack.State,
+			"time": GetTechModifiedProperty(techMods, template, "Pack/Time", +template.Pack.Time),
+		};
+	}
+
 	if (template.Health)
 	{
-		ret.health = +template.Health.Max;
+		ret.health = Math.round(GetTechModifiedProperty(techMods, template, "Health/Max", +template.Health.Max));
 	}
 
 	if (template.Identity)
@@ -443,6 +485,7 @@ GuiInterface.prototype.GetTemplateData = function(player, name)
 		ret.icon = template.Identity.Icon;
 		ret.tooltip =  template.Identity.Tooltip;
 		ret.requiredTechnology = template.Identity.RequiredTechnology;
+		ret.identityClassesString = GetTemplateIdentityClassesString(template);
 	}
 
 	if (template.UnitMotion)
@@ -509,10 +552,11 @@ GuiInterface.prototype.GetTechnologyData = function(player, name)
 	};
 	ret.icon = "technologies/" + template.icon;
 	ret.cost = {
-		"food": +template.cost.food,
-		"wood": +template.cost.wood,
-		"metal": +template.cost.metal,
-		"stone": +template.cost.stone,
+		"food": template.cost ? (+template.cost.food) : 0,
+		"wood": template.cost ? (+template.cost.wood) : 0,
+		"metal": template.cost ? (+template.cost.metal) : 0,
+		"stone": template.cost ? (+template.cost.stone) : 0,
+		"time": template.researchTime ? (+template.researchTime) : 0,
 	}
 	ret.tooltip = template.tooltip;
 	
@@ -568,6 +612,13 @@ GuiInterface.prototype.GetStartedResearch = function(player)
 	return ret;
 }
 
+// Returns the battle state of the player.
+GuiInterface.prototype.GetBattleState = function(player)
+{
+	var cmpBattleDetection = QueryPlayerIDInterface(player, IID_BattleDetection);
+	return cmpBattleDetection.GetState();
+};
+
 // Used to show a red square over GUI elements you can't yet afford.
 GuiInterface.prototype.GetNeededResources = function(player, amounts)
 {
@@ -754,10 +805,19 @@ GuiInterface.prototype.DisplayRallyPoint = function(player, cmd)
  * cmd.template is the name of the entity template, or "" to disable the preview.
  * cmd.x, cmd.z, cmd.angle give the location.
  * 
- * Returns true if the placement is okay (everything is valid and the entity is not obstructed by others).
+ * Returns result object from CheckPlacement:
+ * 	{
+ *		"success":	true iff the placement is valid, else false
+ *		"message":	message to display in UI for invalid placement, else empty string
+ *  }
  */
 GuiInterface.prototype.SetBuildingPlacementPreview = function(player, cmd)
 {
+	var result = {
+		"success": false,
+		"message": "",
+	}
+
 	// See if we're changing template
 	if (!this.placementEntity || this.placementEntity[0] != cmd.template)
 	{
@@ -788,38 +848,31 @@ GuiInterface.prototype.SetBuildingPlacementPreview = function(player, cmd)
 			pos.SetYRotation(cmd.angle);
 		}
 
-		// Check whether it's in a visible or fogged region
-		//	tell GetLosVisibility to force RetainInFog because preview entities set this to false,
-		//	which would show them as hidden instead of fogged
-		var cmpRangeManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager);
-		var visible = (cmpRangeManager && cmpRangeManager.GetLosVisibility(ent, player, true) != "hidden");
-		var validPlacement = false;
+		var cmpOwnership = Engine.QueryInterface(ent, IID_Ownership);
+		cmpOwnership.SetOwner(player);
 
-		if (visible)
-		{	// Check whether it's obstructed by other entities or invalid terrain
-			var cmpBuildRestrictions = Engine.QueryInterface(ent, IID_BuildRestrictions);
-			if (!cmpBuildRestrictions)
-				error("cmpBuildRestrictions not defined");
-
-			validPlacement = (cmpBuildRestrictions && cmpBuildRestrictions.CheckPlacement(player));
-		}
-
-		var ok = (visible && validPlacement);
+		// Check whether building placement is valid
+		var cmpBuildRestrictions = Engine.QueryInterface(ent, IID_BuildRestrictions);
+		if (!cmpBuildRestrictions)
+			error("cmpBuildRestrictions not defined");
+		else
+			result = cmpBuildRestrictions.CheckPlacement();
 
 		// Set it to a red shade if this is an invalid location
 		var cmpVisual = Engine.QueryInterface(ent, IID_Visual);
 		if (cmpVisual)
 		{
-			if (!ok)
+			if (cmd.actorSeed !== undefined)
+				cmpVisual.SetActorSeed(cmd.actorSeed);
+
+			if (!result.success)
 				cmpVisual.SetShadingColour(1.4, 0.4, 0.4, 1);
 			else
 				cmpVisual.SetShadingColour(1, 1, 1, 1);
 		}
-
-		return ok;
 	}
 
-	return false;
+	return result;
 };
 
 /**
@@ -1019,7 +1072,7 @@ GuiInterface.prototype.SetWallPlacementPreview = function(player, cmd)
 	
 	var result = {
 		"pieces": [],
-		"cost": {"food": 0, "wood": 0, "stone": 0, "metal": 0, "population": 0, "populationBonus": 0},
+		"cost": {"food": 0, "wood": 0, "stone": 0, "metal": 0, "population": 0, "populationBonus": 0, "time": 0},
 	};
 	
 	var previewEntities = [];
@@ -1250,6 +1303,9 @@ GuiInterface.prototype.SetWallPlacementPreview = function(player, cmd)
 		// check whether this wall piece can be validly positioned here
 		var validPlacement = false;
 		
+		var cmpOwnership = Engine.QueryInterface(ent, IID_Ownership);
+		cmpOwnership.SetOwner(player);
+		
 		// Check whether it's in a visible or fogged region
 		//  tell GetLosVisibility to force RetainInFog because preview entities set this to false,
 		//	which would show them as hidden instead of fogged
@@ -1264,7 +1320,8 @@ GuiInterface.prototype.SetWallPlacementPreview = function(player, cmd)
 				continue;
 			}
 			
-			validPlacement = (cmpBuildRestrictions && cmpBuildRestrictions.CheckPlacement(player));
+			// TODO: Handle results of CheckPlacement
+			validPlacement = (cmpBuildRestrictions && cmpBuildRestrictions.CheckPlacement().success);
 
 			// If a wall piece has two control groups, it's likely a segment that spans
 			// between two existing towers. To avoid placing a duplicate wall segment,
@@ -1306,6 +1363,7 @@ GuiInterface.prototype.SetWallPlacementPreview = function(player, cmd)
 			result.cost.metal += tplData.cost.metal;
 			result.cost.population += tplData.cost.population;
 			result.cost.populationBonus += tplData.cost.populationBonus;
+			result.cost.time += tplData.cost.time;
 		}
 
 		var canAfford = true;
@@ -1400,6 +1458,7 @@ GuiInterface.prototype.GetFoundationSnapData = function(player, data)
 	
 	if (template.BuildRestrictions.Category == "Dock")
 	{
+		// warning: copied almost identically in helpers/command.js , "GetDockAngle".
 		var cmpTerrain = Engine.QueryInterface(SYSTEM_ENTITY, IID_Terrain);
 		var cmpWaterManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_WaterManager);
 		if (!cmpTerrain || !cmpWaterManager)
@@ -1501,22 +1560,38 @@ function isIdleUnit(ent, idleClass)
 	return (cmpUnitAI && cmpIdentity && cmpUnitAI.IsIdle() && !cmpUnitAI.IsGarrisoned() && idleClass && cmpIdentity.HasClass(idleClass));
 }
 
-GuiInterface.prototype.FindIdleUnit = function(player, data)
+GuiInterface.prototype.FindIdleUnits = function(player, data)
 {
 	var rangeMan = Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager);
-	var playerEntities = rangeMan.GetEntitiesByPlayer(player);
+	var playerEntities = rangeMan.GetEntitiesByPlayer(player).filter( function(e) {
+		var cmpUnitAI = Engine.QueryInterface(e, IID_UnitAI);
+		if (cmpUnitAI)
+			return true;
+		return false;
+	});
 
-	// Find the first matching entity that is after the previous selection,
-	// so that we cycle around in a predictable order
-	for each (var ent in playerEntities)
+	var idleUnits = [];
+	var noFilter = (data.prevUnit == undefined && data.excludeUnits == undefined);
+
+	for (var j = 0; j < playerEntities.length; ++j)
 	{
-		if (ent > data.prevUnit && isIdleUnit(ent, data.idleClass))
-			return ent;
+		var ent = playerEntities[j];
+		if (!isIdleUnit(ent, data.idleClass))
+			continue;
+
+		if (noFilter || ((data.prevUnit == undefined || ent > data.prevUnit) &&
+				(data.excludeUnits == undefined || data.excludeUnits.indexOf(ent) == -1)))
+		{
+			idleUnits.push(ent);
+			playerEntities.splice(j--, 1);
+		}
+
+		if (data.limit && idleUnits.length >= data.limit)
+			break;
 	}
 
-	// No idle entities left in the class
-	return 0;
-};
+	return idleUnits;
+}
 
 GuiInterface.prototype.GetTradingRouteGain = function(player, data)
 {
@@ -1581,6 +1656,18 @@ GuiInterface.prototype.CanAttack = function(player, data)
 	return cmpAttack.CanAttack(data.target);
 };
 
+/*
+ * Returns batch build time.
+ */
+GuiInterface.prototype.GetBatchTime = function(player, data)
+{
+	var cmpProductionQueue = Engine.QueryInterface(data.entity, IID_ProductionQueue);
+	if (!cmpProductionQueue)
+		return 0;
+
+	return cmpProductionQueue.GetBatchTime(data.batchSize);
+};
+
 GuiInterface.prototype.SetPathfinderDebugOverlay = function(player, enabled)
 {
 	var cmpPathfinder = Engine.QueryInterface(SYSTEM_ENTITY, IID_Pathfinder);
@@ -1631,6 +1718,7 @@ var exposedFunctions = {
 	"IsTechnologyResearched": 1,
 	"CheckTechnologyRequirements": 1,
 	"GetStartedResearch": 1,
+	"GetBattleState": 1,
 	"GetNeededResources": 1,
 	"GetNextNotification": 1,
 
@@ -1648,10 +1736,11 @@ var exposedFunctions = {
 	"SetWallPlacementPreview": 1,
 	"GetFoundationSnapData": 1,
 	"PlaySound": 1,
-	"FindIdleUnit": 1,
+	"FindIdleUnits": 1,
 	"GetTradingRouteGain": 1,
 	"GetTradingDetails": 1,
 	"CanAttack": 1,
+	"GetBatchTime": 1,
 
 	"SetPathfinderDebugOverlay": 1,
 	"SetObstructionDebugOverlay": 1,
