@@ -14,13 +14,14 @@ Player.prototype.Init = function()
 	this.maxPop = 300; // maximum population
 	this.trainingBlocked = false; // indicates whether any training queue is currently blocked
 	this.resourceCount = {
-		"food": 300,	
-		"wood": 300,	
-		"metal": 300,	
-		"stone": 300	
+		"food": 300,
+		"wood": 300,
+		"metal": 300,
+		"stone": 300
 	};
 
 	this.team = -1;	// team number of the player, players on the same team will always have ally diplomatic status - also this is useful for team emblems, scoring, etc.
+	this.teamsLocked = false;
 	this.state = "active"; // game state - one of "active", "defeated", "won"
 	this.diplomacy = [];	// array of diplomatic stances for this player with respect to other players (including gaia and self)
 	this.conquestCriticalEntitiesCount = 0; // number of owned units with ConquestCritical class
@@ -29,6 +30,7 @@ Player.prototype.Init = function()
 	this.startCam = undefined;
 	this.controlAllUnits = false;
 	this.isAI = false;
+	this.gatherRateMultiplier = 1;
 	this.cheatsEnabled = true;
 	this.cheatTimeMultiplier = 1;
 };
@@ -73,13 +75,14 @@ Player.prototype.GetColour = function()
 	return this.colour;
 };
 
+// Try reserving num population slots. Returns 0 on success or number of missing slots otherwise.
 Player.prototype.TryReservePopulationSlots = function(num)
 {
 	if (num != 0 && num > (this.GetPopulationLimit() - this.GetPopulationCount()))
-		return false;
+		return num - (this.GetPopulationLimit() - this.GetPopulationCount());
 
 	this.popUsed += num;
-	return true;
+	return 0;
 };
 
 Player.prototype.UnReservePopulationSlots = function(num)
@@ -94,7 +97,7 @@ Player.prototype.GetPopulationCount = function()
 
 Player.prototype.GetPopulationLimit = function()
 {
-	return Math.min(this.maxPop, this.popBonuses);
+	return Math.min(this.GetMaxPopulation(), this.popBonuses);
 };
 
 Player.prototype.SetMaxPopulation = function(max)
@@ -104,7 +107,17 @@ Player.prototype.SetMaxPopulation = function(max)
 
 Player.prototype.GetMaxPopulation = function()
 {
-	return this.maxPop;
+	return Math.round(ApplyTechModificationsToPlayer("Player/MaxPopulation", this.maxPop, this.entity));
+};
+
+Player.prototype.SetGatherRateMultiplier = function(value)
+{
+	this.gatherRateMultiplier = value;
+};
+
+Player.prototype.GetGatherRateMultiplier = function()
+{
+	return this.gatherRateMultiplier;
 };
 
 Player.prototype.IsTrainingBlocked = function()
@@ -142,7 +155,7 @@ Player.prototype.GetResourceCounts = function()
 /**
  * Add resource of specified type to player
  * @param type Generic type of resource (string)
- * @param amount Amount of resource, whick should be added (integer)
+ * @param amount Amount of resource, which should be added (integer)
  */
 Player.prototype.AddResource = function(type, amount)
 {
@@ -173,10 +186,10 @@ Player.prototype.GetNeededResources = function(amounts)
 	return amountsNeeded;
 };
 
-Player.prototype.TrySubtractResources = function(amounts)
+Player.prototype.SubtractResourcesOrNotify = function(amounts)
 {
 	var amountsNeeded = this.GetNeededResources(amounts);
-			
+
 	// If we don't have enough resources, send a notification to the player
 	if (amountsNeeded)
 	{
@@ -188,17 +201,23 @@ Player.prototype.TrySubtractResources = function(amounts)
 		cmpGUIInterface.PushNotification(notification);
 		return false;
 	}
-	else
-	{
-		// Subtract the resources
-		var cmpStatisticsTracker = QueryPlayerIDInterface(this.playerID, IID_StatisticsTracker);
+
+	// Subtract the resources
+	for (var type in amounts)
+		this.resourceCount[type] -= amounts[type];
+
+	return true;
+};
+
+Player.prototype.TrySubtractResources = function(amounts)
+{
+	if (!this.SubtractResourcesOrNotify(amounts))
+		return false;
+
+	var cmpStatisticsTracker = QueryPlayerIDInterface(this.playerID, IID_StatisticsTracker);
+	if (cmpStatisticsTracker)
 		for (var type in amounts)
-		{
-			this.resourceCount[type] -= amounts[type];
-			if (cmpStatisticsTracker)
-				cmpStatisticsTracker.IncreaseResourceUsedCounter(type, amounts[type]);
-		}
-	}
+			cmpStatisticsTracker.IncreaseResourceUsedCounter(type, amounts[type]);
 
 	return true;
 };
@@ -225,7 +244,37 @@ Player.prototype.GetTeam = function()
 
 Player.prototype.SetTeam = function(team)
 {
-	this.team = team;
+	if (!this.teamsLocked)
+	{
+		this.team = team;
+
+		var cmpPlayerManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_PlayerManager);
+		if (cmpPlayerManager && this.team != -1)
+		{
+			// Set all team members as allies
+			for (var i = 0; i < cmpPlayerManager.GetNumPlayers(); ++i)
+			{
+				var cmpPlayer = Engine.QueryInterface(cmpPlayerManager.GetPlayerByID(i), IID_Player);
+				if (this.team == cmpPlayer.GetTeam())
+				{
+					this.SetAlly(i);
+					cmpPlayer.SetAlly(this.playerID);
+				}
+			}
+		}
+
+		Engine.BroadcastMessage(MT_DiplomacyChanged, {"player": this.playerID});
+	}
+};
+
+Player.prototype.SetLockTeams = function(value)
+{
+	this.teamsLocked = value;
+};
+
+Player.prototype.GetLockTeams = function()
+{
+	return this.teamsLocked;
 };
 
 Player.prototype.GetDiplomacy = function()
@@ -235,15 +284,59 @@ Player.prototype.GetDiplomacy = function()
 
 Player.prototype.SetDiplomacy = function(dipl)
 {
+	// Should we check for teamsLocked here?
 	this.diplomacy = dipl;
-	this.UpdateSharedLos();
+	Engine.BroadcastMessage(MT_DiplomacyChanged, {"player": this.playerID});
 };
 
 Player.prototype.SetDiplomacyIndex = function(idx, value)
 {
-	// TODO: send a message too?
-	this.diplomacy[idx] = value;
-	this.UpdateSharedLos();
+	var cmpPlayerManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_PlayerManager);
+	if (!cmpPlayerManager)
+		return;
+
+	var cmpPlayer = Engine.QueryInterface(cmpPlayerManager.GetPlayerByID(idx), IID_Player);
+	if (!cmpPlayer)
+		return;
+
+	if (this.state != "active" || cmpPlayer.state != "active")
+		return;
+
+	// You can have alliances with other players,
+	if (this.teamsLocked)
+	{
+		// but can't stab your team members in the back
+		if (this.team == -1 || cmpPlayer && this.team != cmpPlayer.GetTeam())
+		{
+			// Break alliance or declare war
+			if (Math.min(this.diplomacy[idx],cmpPlayer.diplomacy[this.playerID]) > value)
+			{
+				this.diplomacy[idx] = value;
+				cmpPlayer.SetDiplomacyIndex(this.playerID, value);
+			}
+			else
+			{
+				this.diplomacy[idx] = value;
+			}
+			Engine.BroadcastMessage(MT_DiplomacyChanged, {"player": this.playerID});
+		}
+	}
+	else
+	{
+		// Break alliance or declare war (worsening of relations is mutual)
+		if (Math.min(this.diplomacy[idx],cmpPlayer.diplomacy[this.playerID]) > value)
+		{
+			// This is duplicated because otherwise we get too much recursion
+			this.diplomacy[idx] = value;
+			cmpPlayer.SetDiplomacyIndex(this.playerID, value);
+		}
+		else
+		{
+			this.diplomacy[idx] = value;
+		}
+
+		Engine.BroadcastMessage(MT_DiplomacyChanged, {"player": this.playerID});
+	}
 };
 
 Player.prototype.UpdateSharedLos = function()
@@ -252,12 +345,18 @@ Player.prototype.UpdateSharedLos = function()
 	if (!cmpRangeManager)
 		return;
 
-	// TODO: only check our alliances currently, more advanced checks
-	//	will be needed when we have full diplomacy
+	var cmpPlayerManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_PlayerManager);
+	if (!cmpPlayerManager)
+		return;
+
 	var sharedLos = [];
-	for (var i = 0; i < this.diplomacy.length; ++i)
+	for (var i = 0; i < cmpPlayerManager.GetNumPlayers(); ++i)
 		if (this.IsAlly(i))
-			sharedLos.push(i);
+		{
+			var cmpPlayer = Engine.QueryInterface(cmpPlayerManager.GetPlayerByID(i), IID_Player);
+			if (cmpPlayer && cmpPlayer.IsAlly(this.playerID))
+				sharedLos.push(i);
+		}
 
 	cmpRangeManager.SetSharedLos(this.playerID, sharedLos);
 };
@@ -358,23 +457,19 @@ Player.prototype.IsNeutral = function(id)
 Player.prototype.OnGlobalOwnershipChanged = function(msg)
 {
 	var isConquestCritical = false;
-
 	// Load class list only if we're going to need it
 	if (msg.from == this.playerID || msg.to == this.playerID)
 	{
 		var cmpIdentity = Engine.QueryInterface(msg.entity, IID_Identity);
 		if (cmpIdentity)
 		{
-			var classes = cmpIdentity.GetClassesList();
-			isConquestCritical = classes.indexOf("ConquestCritical") != -1;
+			isConquestCritical = cmpIdentity.HasClass("ConquestCritical");
 		}
 	}
-	
 	if (msg.from == this.playerID)
 	{
 		if (isConquestCritical)
-			this.conquestCriticalEntitiesCount--;	
-
+			this.conquestCriticalEntitiesCount--;
 		var cost = Engine.QueryInterface(msg.entity, IID_Cost);
 		if (cost)
 		{
@@ -382,12 +477,10 @@ Player.prototype.OnGlobalOwnershipChanged = function(msg)
 			this.popBonuses -= cost.GetPopBonus();
 		}
 	}
-	
 	if (msg.to == this.playerID)
 	{
 		if (isConquestCritical)
 			this.conquestCriticalEntitiesCount++;
-			
 		var cost = Engine.QueryInterface(msg.entity, IID_Cost);
 		if (cost)
 		{
@@ -401,6 +494,8 @@ Player.prototype.OnPlayerDefeated = function(msg)
 {
 	this.state = "defeated";
 
+	// TODO: Tribute all resources to this player's active allies (if any)
+
 	// Reassign all player's entities to Gaia
 	var cmpRangeManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager);
 	var entities = cmpRangeManager.GetEntitiesByPlayer(this.playerID);
@@ -428,15 +523,51 @@ Player.prototype.OnPlayerDefeated = function(msg)
 	cmpGUIInterface.PushNotification(notification);
 };
 
+Player.prototype.OnDiplomacyChanged = function()
+{
+	this.UpdateSharedLos();
+};
 
 Player.prototype.SetCheatEnabled = function(flag)
 {
 	this.cheatsEnabled = flag;
-}
+};
 
 Player.prototype.GetCheatEnabled = function(flag)
 {
 	return this.cheatsEnabled;
-}
+};
+
+Player.prototype.TributeResource = function(player, amounts)
+{
+	var cmpPlayerManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_PlayerManager);
+	if (!cmpPlayerManager)
+		return;
+
+	var cmpPlayer = Engine.QueryInterface(cmpPlayerManager.GetPlayerByID(player), IID_Player);
+	if (!cmpPlayer)
+		return;
+
+	if (this.state != "active" || cmpPlayer.state != "active")
+		return;
+
+	if (!this.SubtractResourcesOrNotify(amounts))
+		return;
+
+	cmpPlayer.AddResources(amounts);
+
+	var total = Object.keys(amounts).reduce(function (sum, type){ return sum + amounts[type]; }, 0);
+	var cmpOurStatisticsTracker = QueryPlayerIDInterface(this.playerID, IID_StatisticsTracker);
+	if (cmpOurStatisticsTracker)
+		cmpOurStatisticsTracker.IncreaseTributesSentCounter(total);
+	var cmpTheirStatisticsTracker = QueryPlayerIDInterface(player, IID_StatisticsTracker);
+	if (cmpTheirStatisticsTracker)
+		cmpTheirStatisticsTracker.IncreaseTributesReceivedCounter(total);
+
+	var notification = {"type": "tribute", "player": player, "player1": this.playerID, "amounts": amounts};
+	var cmpGUIInterface = Engine.QueryInterface(SYSTEM_ENTITY, IID_GuiInterface);
+	if (cmpGUIInterface)
+		cmpGUIInterface.PushNotification(notification);
+};
 
 Engine.RegisterComponentType(IID_Player, "Player", Player);
