@@ -6,10 +6,14 @@ function ProductionQueue() {}
 ProductionQueue.prototype.Schema =
 	"<a:help>Allows the building to train new units and research technologies</a:help>" +
 	"<a:example>" +
+		"<BatchTimeModifier>0.7</BatchTimeModifier>" +
 		"<Entities datatype='tokens'>" +
 			"\n    units/{civ}_support_female_citizen\n    units/{civ}_support_trader\n    units/celt_infantry_spearman_b\n  " +
 		"</Entities>" +
 	"</a:example>" +
+	"<element name='BatchTimeModifier' a:help='Modifier that influences the time benefit for batch training'>" +
+		"<ref name='nonNegativeDecimal'/>" +
+	"</element>" +
 	"<optional>" + 
 		"<element name='Entities' a:help='Space-separated list of entity template names that this building can train. The special string \"{civ}\" will be automatically replaced by the building&apos;s four-character civ code'>" +
 			"<attribute name='datatype'>" +
@@ -38,6 +42,7 @@ ProductionQueue.prototype.Init = function()
 	//     "player": 1, // who paid for this batch; we need this to cope with refunds cleanly
 	//     "unitTemplate": "units/example",
 	//     "count": 10,
+	//     "neededSlots": 3, // number of population slots missing for production to begin
 	//     "resources": { "wood": 100, ... },	// resources per unit, multiply by count to get total
 	//     "population": 1,	// population per unit, multiply by count to get total
 	//     "productionStarted": false, // true iff we have reserved population
@@ -123,7 +128,7 @@ ProductionQueue.prototype.GetTechnologiesList = function()
 	
 	var ret = []
 	
-	// This inserts the techs into the correct positions to line up the tehnology pairs
+	// This inserts the techs into the correct positions to line up the technology pairs
 	for (var i = 0; i < techList.length; i++)
 	{
 		var tech = techList[i];
@@ -184,25 +189,18 @@ ProductionQueue.prototype.AddBatch = function(templateName, type, count, metadat
 				return;
 			
 			// Apply a time discount to larger batches.
-			// TODO: work out what equation we should use here.
-			var timeMult = Math.pow(count, 0.7) * cmpPlayer.cheatTimeMultiplier;
+			var timeMult = this.GetBatchTime(count);
 			
 			// We need the costs after tech modifications
 			// Obviously we don't have the entities yet, so we must use template data
 			var costs = {};
 			var totalCosts = {};
-			var buildTime = +template.Cost.BuildTime;
-			
-			var cmpTechnologyManager = QueryOwnerInterface(this.entity, IID_TechnologyManager);
-			if (cmpTechnologyManager)
-				buildTime = cmpTechnologyManager.ApplyModificationsTemplate("Cost/BuildTime", buildTime, template);
+			var buildTime = ApplyTechModificationsToTemplate("Cost/BuildTime", +template.Cost.BuildTime, this.entity, template);
 			var time = timeMult * buildTime;
 
 			for (var r in template.Cost.Resources)
 			{
-				costs[r] = +template.Cost.Resources[r];
-				if (cmpTechnologyManager)
-					costs[r] = cmpTechnologyManager.ApplyModificationsTemplate("Cost/Resources/"+r, costs[r], template);
+				costs[r] = ApplyTechModificationsToTemplate("Cost/Resources/"+r, +template.Cost.Resources[r], this.entity, template);
 				totalCosts[r] = Math.floor(count * costs[r]);
 			}
 
@@ -212,6 +210,14 @@ ProductionQueue.prototype.AddBatch = function(templateName, type, count, metadat
 			if (!cmpPlayer.TrySubtractResources(totalCosts))
 				return;
 
+			// Update entity count in the EntityLimits component
+			if (template.TrainingRestrictions)
+			{
+				var unitCategory = template.TrainingRestrictions.Category;
+				var cmpPlayerEntityLimits = QueryOwnerInterface(this.entity, IID_EntityLimits);
+				cmpPlayerEntityLimits.IncreaseCount(unitCategory, count);
+			}
+
 			this.queue.push({
 				"id": this.nextID++,
 				"player": cmpPlayer.GetPlayerID(),
@@ -307,9 +313,22 @@ ProductionQueue.prototype.RemoveBatch = function(id)
 		
 		var cmpPlayer = QueryPlayerIDInterface(item.player, IID_Player);
 
+		// Update entity count in the EntityLimits component
+		if (item.unitTemplate)
+		{
+			var cmpTempMan = Engine.QueryInterface(SYSTEM_ENTITY, IID_TemplateManager);
+			var template = cmpTempMan.GetTemplate(item.unitTemplate);
+			if (template.TrainingRestrictions)
+			{
+				var unitCategory = template.TrainingRestrictions.Category;
+				var cmpPlayerEntityLimits = QueryPlayerIDInterface(item.player, IID_EntityLimits);
+				cmpPlayerEntityLimits.DecreaseCount(unitCategory, item.count);
+			}
+		}
+
 		// Refund the resource cost for this batch
 		var totalCosts = {};
-		var cmpStatisticsTracker = QueryOwnerInterface(this.entity, IID_StatisticsTracker);
+		var cmpStatisticsTracker = QueryPlayerIDInterface(item.player, IID_StatisticsTracker);
 		for each (var r in ["food", "wood", "stone", "metal"])
 		{
 			totalCosts[r] = Math.floor(item.count * item.resources[r]);
@@ -353,6 +372,7 @@ ProductionQueue.prototype.GetQueue = function()
 			"unitTemplate": item.unitTemplate,
 			"technologyTemplate": item.technologyTemplate,
 			"count": item.count,
+			"neededSlots": item.neededSlots,
 			"progress": 1-(item.timeRemaining/item.timeTotal),
 			"metadata": item.metadata,
 		});
@@ -373,6 +393,19 @@ ProductionQueue.prototype.ResetQueue = function()
 		this.RemoveBatch(this.queue[0].id);
 };
 
+/*
+ * Returns batch build time.
+ */
+ProductionQueue.prototype.GetBatchTime = function(batchSize)
+{
+	var cmpPlayer = QueryOwnerInterface(this.entity, IID_Player);
+
+	var batchTimeModifier = ApplyTechModificationsToEntity("ProductionQueue/BatchTimeModifier", +this.template.BatchTimeModifier, this.entity);
+
+	// TODO: work out what equation we should use here.
+	return Math.pow(batchSize, batchTimeModifier) * cmpPlayer.cheatTimeMultiplier;
+};
+
 ProductionQueue.prototype.OnOwnershipChanged = function(msg)
 {
 	if (msg.from != -1)
@@ -422,7 +455,19 @@ ProductionQueue.prototype.SpawnUnits = function(templateName, count, metadata)
 		//	so only create them once and use as needed
 		for (var i = 0; i < count; ++i)
 		{
-			this.entityCache.push(Engine.AddEntity(templateName));
+			var ent = Engine.AddEntity(templateName);
+			this.entityCache.push(ent);
+
+			// Decrement entity count in the EntityLimits component
+			// since it will be increased by EntityLimits.OnGlobalOwnershipChanged function,
+			// i.e. we replace a 'trained' entity to an 'alive' one
+			var cmpTrainingRestrictions = Engine.QueryInterface(ent, IID_TrainingRestrictions);
+			if (cmpTrainingRestrictions)
+			{
+				var unitCategory = cmpTrainingRestrictions.GetCategory();
+				var cmpPlayerEntityLimits = QueryOwnerInterface(this.entity, IID_EntityLimits);
+				cmpPlayerEntityLimits.DecrementCount(unitCategory);
+			}
 		}
 	}
 
@@ -506,9 +551,10 @@ ProductionQueue.prototype.ProgressTimeout = function(data)
 			{
 				// Batch's training hasn't started yet.
 				// Try to reserve the necessary population slots
-				if (item.unitTemplate && !cmpPlayer.TryReservePopulationSlots(item.population * item.count))
+				item.neededSlots = cmpPlayer.TryReservePopulationSlots(item.population * item.count);
+				if (item.neededSlots)
 				{
-					// No slots available - don't train this batch now
+					// Not enough slots available - don't train this batch now
 					// (we'll try again on the next timeout)
 
 					// Set flag that training is blocked
@@ -534,6 +580,8 @@ ProductionQueue.prototype.ProgressTimeout = function(data)
 		if (item.timeRemaining > time)
 		{
 			item.timeRemaining -= time;
+			// send a message for the AIs.
+			Engine.PostMessage(this.entity, MT_ProductionQueueChanged, { });
 			break;
 		}
 
