@@ -1,13 +1,14 @@
 Engine.LoadComponentScript("interfaces/Attack.js");
 Engine.LoadComponentScript("interfaces/Barter.js");
 Engine.LoadComponentScript("interfaces/Builder.js");
-Engine.LoadComponentScript("interfaces/BuildLimits.js");
 Engine.LoadComponentScript("interfaces/DamageReceiver.js");
+Engine.LoadComponentScript("interfaces/EntityLimits.js");
 Engine.LoadComponentScript("interfaces/Foundation.js");
 Engine.LoadComponentScript("interfaces/GarrisonHolder.js");
 Engine.LoadComponentScript("interfaces/Gate.js");
 Engine.LoadComponentScript("interfaces/Heal.js");
 Engine.LoadComponentScript("interfaces/Health.js");
+Engine.LoadComponentScript("interfaces/Pack.js");
 Engine.LoadComponentScript("interfaces/ProductionQueue.js");
 Engine.LoadComponentScript("interfaces/Promotion.js");
 Engine.LoadComponentScript("interfaces/RallyPoint.js");
@@ -61,13 +62,15 @@ AddMock(100, IID_Player, {
 	IsTrainingBlocked: function() { return false; },
 	GetState: function() { return "active"; },
 	GetTeam: function() { return -1; },
+	GetLockTeams: function() { return false; },
 	GetDiplomacy: function() { return [-1, 1]; },
 	GetConquestCriticalEntitiesCount: function() { return 1; },
 	IsAlly: function() { return false; },
+	IsNeutral: function() { return false; },
 	IsEnemy: function() { return true; },
 });
 
-AddMock(100, IID_BuildLimits, {
+AddMock(100, IID_EntityLimits, {
 	GetLimits: function() { return {"Foo": 10}; },
 	GetCounts: function() { return {"Foo": 5}; },
 });
@@ -112,21 +115,61 @@ AddMock(101, IID_Player, {
 	IsTrainingBlocked: function() { return false; },
 	GetState: function() { return "active"; },
 	GetTeam: function() { return -1; },
+	GetLockTeams: function() {return false; },
 	GetDiplomacy: function() { return [-1, 1]; },
 	GetConquestCriticalEntitiesCount: function() { return 1; },
 	IsAlly: function() { return true; },
+	IsNeutral: function() { return false; },
 	IsEnemy: function() { return false; },
 });
 
-AddMock(101, IID_BuildLimits, {
+AddMock(101, IID_EntityLimits, {
 	GetLimits: function() { return {"Bar": 20}; },
 	GetCounts: function() { return {"Bar": 0}; },
 });
 
-AddMock(101, IID_TechnologyManager, {
+AddMock(100, IID_TechnologyManager, {
 	IsTechnologyResearched: function(tech) { if (tech == "phase_village") return true; else return false; },
+	GetQueuedResearch: function() { return {}; },
+	GetStartedResearch: function() { return {}; },
+	GetResearchedTechs: function() { return {}; },
+	GetClassCounts: function() { return {}; },
+	GetTypeCountsByClass: function() { return {}; },
 	GetTechModifications: function() { return {}; },
 });
+AddMock(100, IID_StatisticsTracker, {
+		GetStatistics: function() {
+		return {
+		"unitsTrained": 10,
+		"unitsLost": 9,
+		"buildingsConstructed": 5,
+		"buildingsLost": 4,
+		"civCentresBuilt": 1,
+		"resourcesGathered": {
+		"food": 100,
+		"wood": 0,
+		"metal": 0,
+		"stone": 0,
+		"vegetarianFood": 0,
+		},
+		"treasuresCollected": 0,
+		"percentMapExplored": 10,
+		};
+		},
+		IncreaseTrainedUnitsCounter: function() { return 1; },
+		IncreaseConstructedBuildingsCounter: function() { return 1; },
+		IncreaseBuiltCivCentresCounter: function() { return 1; },
+		});
+
+AddMock(101, IID_TechnologyManager, {
+		IsTechnologyResearched: function(tech) { if (tech == "phase_village") return true; else return false; },
+		GetQueuedResearch: function() { return {}; },
+		GetStartedResearch: function() { return {}; },
+		GetResearchedTechs: function() { return {}; },
+		GetClassCounts: function() { return {}; },
+		GetTypeCountsByClass: function() { return {}; },
+		GetTechModifications: function() { return {}; },
+});
 
 AddMock(101, IID_StatisticsTracker, {
 	GetStatistics: function() { 
@@ -168,12 +211,19 @@ TS_ASSERT_UNEVAL_EQUALS(cmp.GetSimulationState(), {
 			trainingBlocked: false,
 			state: "active",
 			team: -1,
-			phase: "",
-			isAlly: [false, false, false],
-			isEnemy: [true, true, true],
-			buildLimits: {"Foo": 10},
-			buildCounts: {"Foo": 5},
+			teamsLocked: false,
+			phase: "village",
+			isAlly: [false, false],
+			isNeutral: [false, false],
+			isEnemy: [true, true],
+			entityLimits: {"Foo": 10},
+			entityCounts: {"Foo": 5},
 			techModifications: {},
+			researchQueued: {},
+			researchStarted: {},
+			researchedTechs: {},
+			classCounts: {},
+			typeCountsByClass: {},
 		},
 		{
 			name: "Player 2",
@@ -186,12 +236,19 @@ TS_ASSERT_UNEVAL_EQUALS(cmp.GetSimulationState(), {
 			trainingBlocked: false,
 			state: "active",
 			team: -1,
+			teamsLocked: false,
 			phase: "village",
-			isAlly: [true, true, true],
-			isEnemy: [false, false, false],
-			buildLimits: {"Bar": 20},
-			buildCounts: {"Bar": 0},
+			isAlly: [true, true],
+			isNeutral: [false, false],
+			isEnemy: [false, false],
+			entityLimits: {"Bar": 20},
+			entityCounts: {"Bar": 0},
 			techModifications: {},
+			researchQueued: {},
+			researchStarted: {},
+			researchedTechs: {},
+			classCounts: {},
+			typeCountsByClass: {},
 		}
 	],
 	circularMap: false,
@@ -211,12 +268,19 @@ TS_ASSERT_UNEVAL_EQUALS(cmp.GetExtendedSimulationState(), {
 			trainingBlocked: false,
 			state: "active",
 			team: -1,
-			phase: "",
-			isAlly: [false, false, false],
-			isEnemy: [true, true, true],
-			buildLimits: {"Foo": 10},
-			buildCounts: {"Foo": 5},
+			teamsLocked: false,
+			phase: "village",
+			isAlly: [false, false],
+			isNeutral: [false, false],
+			isEnemy: [true, true],
+			entityLimits: {"Foo": 10},
+			entityCounts: {"Foo": 5},
 			techModifications: {},
+			researchQueued: {},
+			researchStarted: {},
+			researchedTechs: {},
+			classCounts: {},
+			typeCountsByClass: {},
 			statistics: {
 				unitsTrained: 10,
 				unitsLost: 9,
@@ -245,12 +309,19 @@ TS_ASSERT_UNEVAL_EQUALS(cmp.GetExtendedSimulationState(), {
 			trainingBlocked: false,
 			state: "active",
 			team: -1,
+			teamsLocked: false,
 			phase: "village",
-			isAlly: [true, true, true],
-			isEnemy: [false, false, false],
-			buildLimits: {"Bar": 20},
-			buildCounts: {"Bar": 0},
+			isAlly: [true, true],
+			isNeutral: [false, false],
+			isEnemy: [false, false],
+			entityLimits: {"Bar": 20},
+			entityCounts: {"Bar": 0},
 			techModifications: {},
+			researchQueued: {},
+			researchStarted: {},
+			researchedTechs: {},
+			classCounts: {},
+			typeCountsByClass: {},
 			statistics: {
 				unitsTrained: 10,
 				unitsLost: 9,
