@@ -1,13 +1,18 @@
 ////////////////////////////////////////////////////////////////////////////////////////////////
 // Constants
-const DEFAULT_NETWORKED_MAP = "Acropolis 1";
-const DEFAULT_OFFLINE_MAP = "Acropolis 1";
+const DEFAULT_NETWORKED_MAP = "Punjab 01";
+const DEFAULT_OFFLINE_MAP = "Punjab 01";
 
 // TODO: Move these somewhere like simulation\data\game_types.json, Atlas needs them too
 const VICTORY_TEXT = ["Conquest", "None"];
 const VICTORY_DATA = ["conquest", "endless"];
 const VICTORY_DEFAULTIDX = 0;
-
+const POPULATION_CAP = ["50", "100", "150", "200", "250", "300", "Unlimited"];
+const POPULATION_CAP_DATA = [50, 100, 150, 200, 250, 300, 10000];
+const POPULATION_CAP_DEFAULTIDX = 5;
+const STARTING_RESOURCES = ["Very Low", "Low", "Medium", "High", "Very High", "Deathmatch"];
+const STARTING_RESOURCES_DATA = [100, 300, 500, 1000, 3000, 50000];
+const STARTING_RESOURCES_DEFAULTIDX = 1;
 // Max number of players for any map
 const MAX_PLAYERS = 8;
 
@@ -53,7 +58,6 @@ Naval maps are recommended to be played with human opponents only.";
 // tick handler
 var g_LoadingState = 0; // 0 = not started, 1 = loading, 2 = loaded
 
-
 ////////////////////////////////////////////////////////////////////////////////////////////////
 
 function init(attribs)
@@ -81,9 +85,7 @@ function init(attribs)
 function initMain()
 {
 	// Load AI list and hide deprecated AIs
-	g_AIs = Engine.GetAIs().filter( function(ai) {
-		return !ai.data.hidden;
-	});
+	g_AIs = Engine.GetAIs();
 
 	// Sort AIs by displayed name
 	g_AIs.sort(function (a, b) {
@@ -134,6 +136,40 @@ function initMain()
 		numPlayersSelection.list_data = players;
 		numPlayersSelection.selected = MAX_PLAYERS - 1;
 
+		var populationCaps = getGUIObjectByName("populationCap");
+		populationCaps.list = POPULATION_CAP;
+		populationCaps.list_data = POPULATION_CAP_DATA;
+		populationCaps.selected = POPULATION_CAP_DEFAULTIDX;
+		populationCaps.onSelectionChange = function()
+		{
+			if (this.selected != -1)
+			{
+				g_GameAttributes.settings.PopulationCap = POPULATION_CAP_DATA[this.selected];
+			}
+			
+			if (!g_IsInGuiUpdate)
+			{
+				updateGameAttributes();
+			}
+		}
+		
+		var startingResourcesL = getGUIObjectByName("startingResources");
+		startingResourcesL.list = STARTING_RESOURCES;
+		startingResourcesL.list_data = STARTING_RESOURCES_DATA;
+		startingResourcesL.selected = STARTING_RESOURCES_DEFAULTIDX;
+		startingResourcesL.onSelectionChange = function()
+		{
+			if (this.selected != -1)
+			{
+				g_GameAttributes.settings.StartingResources = STARTING_RESOURCES_DATA[this.selected];
+			}
+			
+			if (!g_IsInGuiUpdate)
+			{
+				updateGameAttributes();
+			}
+		}
+		
 		var victoryConditions = getGUIObjectByName("victoryCondition");
 		victoryConditions.list = VICTORY_TEXT;
 		victoryConditions.list_data = VICTORY_DATA;
@@ -207,7 +243,9 @@ function initMain()
 		getGUIObjectByName("mapFilterText").hidden = false;
 		getGUIObjectByName("mapSelectionText").hidden = false;
 		getGUIObjectByName("mapSelection").hidden = true;
-
+		getGUIObjectByName("victoryConditionText").hidden = false;
+		getGUIObjectByName("victoryCondition").hidden = true;
+		
 		// Disable player and game options controls
 		// TODO: Shouldn't players be able to choose their own assignment?
 		for (var i = 0; i < MAX_PLAYERS; ++i)
@@ -218,10 +256,6 @@ function initMain()
 		}
 
 		getGUIObjectByName("numPlayersSelection").hidden = true;
-
-		// Disable "start game" button
-		// TODO: Perhaps replace this with a "ready" button, and require host to wait?
-		getGUIObjectByName("startGame").enabled = false;
 	}
 
 	// Set up multiplayer/singleplayer bits:
@@ -245,6 +279,7 @@ function initMain()
 			getGUIObjectByName("enableCheatsText").hidden = false;
 		}
 	}
+
 	// Settings for all possible player slots
 	var boxSpacing = 32;
 	for (var i = 0; i < MAX_PLAYERS; ++i)
@@ -440,7 +475,7 @@ function initCivNameList()
 	var civListCodes = [ civ.code for each (civ in civList) ];
 
 	//  Add random civ to beginning of list 
-	civListNames.unshift("[color=\"255 160 10 255\"]Random"); 
+	civListNames.unshift("[color=\"orange\"]Random"); 
 	civListCodes.unshift("random"); 
 	
 	// Update the dropdowns
@@ -491,7 +526,9 @@ function initMapNameList()
 
 	// Alphabetically sort the list, ignoring case
 	mapList.sort(sortNameIgnoreCase);
-
+	if (g_GameAttributes.mapType == "random")
+		mapList.unshift({ "name": "[color=\"orange\"]Random[/color]", "file": "random" });
+	
 	var mapListNames = [ map.name for each (map in mapList) ];
 	var mapListFiles = [ map.file for each (map in mapList) ];
 
@@ -515,6 +552,12 @@ function loadMapData(name)
 	{
 		return undefined;
 	}
+	
+	if (name == "random")
+	{
+		g_MapData[name] = {settings : {"Name" : "Random", "Description" : "Randomly selects a map from the list"}};
+		return g_MapData[name];
+	}
 
 	if (!g_MapData[name])
 	{
@@ -610,6 +653,19 @@ function selectNumPlayers(num)
 		}
 	}
 
+	// Some players may have lost their assigned slot
+	for (var guid in g_PlayerAssignments)
+	{
+		var player = g_PlayerAssignments[guid].player;
+		if (player > num)
+		{
+			if (g_IsNetworked)
+				Engine.AssignNetworkPlayer(player, "");
+			else
+				g_PlayerAssignments = { "local": { "name": "You", "player": 1, "civ": "", "team": -1} };
+		}
+	}
+
 	updateGameAttributes();
 }
 
@@ -712,11 +768,10 @@ function selectMap(name)
 	// Copy any new settings
 	g_GameAttributes.map = name;
 	g_GameAttributes.script = mapSettings.Script;
-	for (var prop in mapSettings)
-	{
-		g_GameAttributes.settings[prop] = mapSettings[prop];
-	}
-
+	if (mapData !== "Random")
+		for (var prop in mapSettings)
+			g_GameAttributes.settings[prop] = mapSettings[prop];
+	
 	// Use default AI if the map doesn't specify any explicitly
 	for (var i = 0; i < g_GameAttributes.settings.PlayerData.length; ++i)
 	{
@@ -724,6 +779,10 @@ function selectMap(name)
 		{
 			g_GameAttributes.settings.PlayerData[i].AI = g_DefaultPlayerData[i].AI;
 		}
+		if (!('AIDiff' in g_GameAttributes.settings.PlayerData[i]))
+		{
+			g_GameAttributes.settings.PlayerData[i].AIDiff = g_DefaultPlayerData[i].AIDiff;
+		}
 	}
 	
 	// Reset player assignments on map change
@@ -763,14 +822,60 @@ function launchGame()
 		return;
 	}
 	
+	if (g_GameAttributes.map == "random")
+		selectMap(getGUIObjectByName("mapSelection").list_data[Math.floor(Math.random() *
+			(getGUIObjectByName("mapSelection").list.length - 1)) + 1]);
+
+	g_GameAttributes.settings.mapType = g_GameAttributes.mapType;
 	var numPlayers = g_GameAttributes.settings.PlayerData.length; 
 	// Assign random civilizations to players with that choice 
 	//  (this is synchronized because we're the host) 
-	var civs = [ civ.Code for each (civ in g_CivData) if (civ.SelectableInGameSetup !== false) ]; 
+	var cultures = [];
+	for each (civ in g_CivData)
+		if ((civ.Culture !== undefined)&&(cultures.indexOf(civ.Culture) < 0)&&(civ.SelectableInGameSetup == undefined)||(civ.SelectableInGameSetup))
+			cultures.push(civ.Culture);
+	var allcivs = new Array(cultures.length);
+	for (var i = 0; i < allcivs.length; ++i)
+		allcivs[i] = [];
+	for each (civ in g_CivData)
+		if ((civ.Culture !== undefined)&&(civ.SelectableInGameSetup == undefined)||(civ.SelectableInGameSetup))
+			allcivs[cultures.indexOf(civ.Culture)].push(civ.Code);
+	
+	const romanNumbers = [undefined, "I", "II", "III", "IV", "V", "VI", "VII", "VIII"];
 	for (var i = 0; i < numPlayers; ++i) 
 	{ 
+		civs = allcivs[Math.floor(Math.random()*allcivs.length)];
+		
 		if (g_GameAttributes.settings.PlayerData[i].Civ == "random") 
 			g_GameAttributes.settings.PlayerData[i].Civ = civs[Math.floor(Math.random()*civs.length)]; 
+		// Setting names for AI players. Check if the player is AI and the match is not a scenario
+		if ((g_GameAttributes.mapType !== "scenario")&&(g_GameAttributes.settings.PlayerData[i].AI))
+		{
+			// Get the civ specific names
+			if (g_CivData[g_GameAttributes.settings.PlayerData[i].Civ].AINames !== undefined)
+			{
+				var civAINames = shuffleArray(g_CivData[g_GameAttributes.settings.PlayerData[i].Civ].AINames);
+			}
+			else
+			{
+				var civAINames = [g_CivData[g_GameAttributes.settings.PlayerData[i].Civ].Name];
+			}
+			// Choose the name
+			var usedName = 0;
+			if (i < civAINames.length)
+				var chosenName = civAINames[i];
+			else 
+				var chosenName = civAINames[Math.floor(Math.random() * civAINames.length)];
+			for (var j = 0; j < numPlayers; ++j) 
+				if (g_GameAttributes.settings.PlayerData[j].Name.indexOf(chosenName) !== -1)
+					usedName++;
+			
+			// Assign civ specific names to AI players
+			if (usedName)
+				g_GameAttributes.settings.PlayerData[i].Name = chosenName + " " + romanNumbers[usedName+1];
+			else
+				g_GameAttributes.settings.PlayerData[i].Name = chosenName;
+		}
 	} 
 	
 	if (g_IsNetworked)
@@ -825,6 +930,10 @@ function onGameAttributesChange()
 		var mapSelectionBox = getGUIObjectByName("mapSelection");
 		mapSelectionBox.selected = mapSelectionBox.list_data.indexOf(mapName);
 		getGUIObjectByName("mapSelectionText").caption = getMapDisplayName(mapName);
+		var populationCapBox = getGUIObjectByName("populationCap");
+		populationCapBox.selected = populationCapBox.list_data.indexOf(mapSettings.PopulationCap);
+		var startingResourcesBox = getGUIObjectByName("startingResources");
+		startingResourcesBox.selected = startingResourcesBox.list_data.indexOf(mapSettings.StartingResources);
 		initMapNameList();
 	}
 
@@ -835,6 +944,8 @@ function onGameAttributesChange()
 	var lockTeams = getGUIObjectByName("lockTeams");
 	var mapSize = getGUIObjectByName("mapSize");
 	var enableCheats = getGUIObjectByName("enableCheats");
+	var populationCap = getGUIObjectByName("populationCap");
+	var startingResources = getGUIObjectByName("startingResources");
 	
 	var numPlayersText= getGUIObjectByName("numPlayersText");
 	var mapSizeText = getGUIObjectByName("mapSizeText");
@@ -842,11 +953,17 @@ function onGameAttributesChange()
 	var victoryConditionText = getGUIObjectByName("victoryConditionText");
 	var lockTeamsText = getGUIObjectByName("lockTeamsText");
 	var enableCheatsText = getGUIObjectByName("enableCheatsText");
+	var populationCapText = getGUIObjectByName("populationCapText");
+	var startingResourcesText = getGUIObjectByName("startingResourcesText");
 	
 	var sizeIdx = (g_MapSizes.tiles.indexOf(mapSettings.Size) != -1 ? g_MapSizes.tiles.indexOf(mapSettings.Size) : g_MapSizes.default);
 	var victoryIdx = (VICTORY_DATA.indexOf(mapSettings.GameType) != -1 ? VICTORY_DATA.indexOf(mapSettings.GameType) : VICTORY_DEFAULTIDX);
 	enableCheats.checked = (g_GameAttributes.settings.CheatsEnabled === undefined || !g_GameAttributes.settings.CheatsEnabled ? false : true)
 	enableCheatsText.caption = (enableCheats.checked ? "Yes" : "No");
+	populationCap.selected = (POPULATION_CAP_DATA.indexOf(mapSettings.PopulationCap) != -1 ? POPULATION_CAP_DATA.indexOf(mapSettings.PopulationCap) : POPULATION_CAP_DEFAULTIDX);
+	populationCapText.caption = POPULATION_CAP[populationCap.selected];
+	startingResources.selected = (STARTING_RESOURCES_DATA.indexOf(mapSettings.StartingResources) != -1 ? STARTING_RESOURCES_DATA.indexOf(mapSettings.StartingResources) : STARTING_RESOURCES_DEFAULTIDX);
+	startingResourcesText.caption = STARTING_RESOURCES[startingResources.selected];
 	// Handle map type specific logic
 	switch (g_GameAttributes.mapType)
 	{
@@ -859,13 +976,17 @@ function onGameAttributesChange()
 			revealMap.hidden = false;
 			victoryCondition.hidden = false;
 			lockTeams.hidden = false;
+			populationCap.hidden = false;
+			startingResources.hidden = false;
 			
 			numPlayersText.hidden = true;
 			mapSizeText.hidden = true;
 			revealMapText.hidden = true;
 			victoryConditionText.hidden = true;
 			lockTeamsText.hidden = true;
-
+			populationCapText.hidden = true;
+			startingResourcesText.hidden = true;
+			
 			// Update map preview
 			getGUIObjectByName("mapPreview").sprite = "cropped:(0.78125,0.5859375)session/icons/mappreview/" + getMapPreview(mapName);
 			
@@ -877,7 +998,7 @@ function onGameAttributesChange()
 			victoryConditionText.caption = "Victory condition:";
 			victoryCondition.selected = victoryIdx;
 			lockTeamsText.caption = "Teams locked:";
-			lockTeams.checked =  (mapSettings.LockTeams === undefined || mapSettings.LockTeams ? true : false);
+			lockTeams.checked = (mapSettings.LockTeams ? true : false);
 		}
 		else
 		{
@@ -887,15 +1008,18 @@ function onGameAttributesChange()
 			revealMapText.hidden = false;
 			victoryConditionText.hidden = false;
 			lockTeamsText.hidden = false;
-			
+			populationCap.hidden = true;
+			populationCapText.hidden = false;
+			startingResources.hidden = true;
+			startingResourcesText.hidden = false;
 			// Update map preview
 			getGUIObjectByName("mapPreview").sprite = "cropped:(0.78125,0.5859375)session/icons/mappreview/" + getMapPreview(mapName);
-			
+
 			numPlayersText.caption = numPlayers;
 			mapSizeText.caption = g_MapSizes.names[sizeIdx];
 			revealMapText.caption = (mapSettings.RevealMap ? "Yes" : "No");
 			victoryConditionText.caption = VICTORY_TEXT[victoryIdx];
-			lockTeamsText.caption = (mapSettings.LockTeams === undefined || mapSettings.LockTeams ? "Yes" : "No");
+			lockTeamsText.caption = (mapSettings.LockTeams ? "Yes" : "No");
 		}
 
 		break;
@@ -912,14 +1036,19 @@ function onGameAttributesChange()
 		revealMapText.hidden = false;
 		victoryConditionText.hidden = false;
 		lockTeamsText.hidden = false;
-
+		populationCap.hidden = true;
+		populationCapText.hidden = false;
+		startingResources.hidden = true;
+		startingResourcesText.hidden = false;
+		
 		// Update map preview
 		getGUIObjectByName("mapPreview").sprite = "cropped:(0.78125,0.5859375)session/icons/mappreview/" + getMapPreview(mapName);
 		numPlayersText.caption = numPlayers;
 		mapSizeText.caption = "Default";
 		revealMapText.caption = (mapSettings.RevealMap ? "Yes" : "No");
 		victoryConditionText.caption = VICTORY_TEXT[victoryIdx];
-		lockTeamsText.caption = (mapSettings.LockTeams === undefined || mapSettings.LockTeams  ? "Yes" : "No");
+		lockTeamsText.caption = (mapSettings.LockTeams ? "Yes" : "No");
+		getGUIObjectByName("populationCap").selected = POPULATION_CAP_DEFAULTIDX;
 
 		break;
 
@@ -977,7 +1106,7 @@ function onGameAttributesChange()
 				// Set text values
 				if (civ == "random")
 				{
-					pCivText.caption = "[color=\"255 160 10 255\"]Random";
+					pCivText.caption = "[color=\"orange\"]Random";
 				}
 				else
 				{
@@ -1027,6 +1156,7 @@ function updatePlayerList()
 	var assignments = [];
 	var aiAssignments = {};
 	var noAssignment;
+	var assignedCount = 0;
 
 	for (var guid in g_PlayerAssignments)
 	{
@@ -1037,10 +1167,33 @@ function updatePlayerList()
 		hostNameList.push(name);
 		hostGuidList.push(guid);
 		assignments[player] = hostID;
+
+		if (player != 255)
+			assignedCount++;
 	}
 
+	// Only enable start button if we have enough assigned players
+	if (g_IsController)
+		getGUIObjectByName("startGame").enabled = (assignedCount > 0);
+
 	for each (var ai in g_AIs)
 	{
+		if (ai.data.hidden) 
+		{
+			// If the map uses a hidden AI then don't hide it
+			var usedByMap = false;
+			for (var i = 0; i < MAX_PLAYERS; ++i) {
+				if (i < g_GameAttributes.settings.PlayerData.length &&
+				    g_GameAttributes.settings.PlayerData[i].AI == ai.id)
+				{
+					usedByMap = true;
+				}
+			}
+			if (!usedByMap)
+			{
+				continue;
+			}
+		}
 		// Give AI a different color so it stands out
 		aiAssignments[ai.id] = hostNameList.length;
 		hostNameList.push("[color=\"70 150 70 255\"]AI: " + ai.data.name);
@@ -1070,12 +1223,15 @@ function updatePlayerList()
 				var aiId = g_GameAttributes.settings.PlayerData[playerSlot].AI;
 				if (aiId)
 				{
-					selection = aiAssignments[aiId];
+					// Check for a valid AI
+					if (aiId in aiAssignments)
+						selection = aiAssignments[aiId];
+					else
+						warn("AI \""+aiId+"\" not present. Defaulting to unassigned.");
 				}
-				else
-				{
+
+				if (!selection)
 					selection = noAssignment;
-				}
 
 				// Since no human is assigned, show the AI config button
 				if (g_IsController)
@@ -1086,9 +1242,11 @@ function updatePlayerList()
 						Engine.PushGuiPage("page_aiconfig.xml", {
 							ais: g_AIs,
 							id: g_GameAttributes.settings.PlayerData[playerSlot].AI,
+							difficulty: g_GameAttributes.settings.PlayerData[playerSlot].AIDiff,
 							callback: function(ai) {
 								g_GameAttributes.settings.PlayerData[playerSlot].AI = ai.id;
-
+								g_GameAttributes.settings.PlayerData[playerSlot].AIDiff = ai.difficulty;
+										   
 								if (g_IsNetworked)
 								{
 									Engine.SetNetworkGameAttributes(g_GameAttributes);
@@ -1274,6 +1432,11 @@ function addChatMessage(msg)
 	getGUIObjectByName("chatText").caption = g_ChatMessages.join("\n");
 }
 
+function toggleMoreOptions()
+{
+	getGUIObjectByName("moreOptions").hidden = !getGUIObjectByName("moreOptions").hidden;
+}
+
 ////////////////////////////////////////////////////////////////////////////////////////////////
 // Basic map filters API
 
@@ -1356,7 +1519,3 @@ function keywordTestOR(keywords, matches)
 	}
 	return false;
 }
-
-
-
-
