@@ -47,6 +47,29 @@ function ProcessCommand(player, cmd)
 		cmpGuiInterface.PushNotification({"type": "quit"});
 		break;
 
+	case "diplomacy":
+		switch(cmd.to)
+		{
+		case "ally":
+			cmpPlayer.SetAlly(cmd.player);
+			break;
+		case "neutral":
+			cmpPlayer.SetNeutral(cmd.player);
+			break;
+		case "enemy":
+			cmpPlayer.SetEnemy(cmd.player);
+			break;
+		default:
+			warn("Invalid command: Could not set "+player+" diplomacy status of player "+cmd.player+" to "+cmd.to);
+		}
+		var cmpGuiInterface = Engine.QueryInterface(SYSTEM_ENTITY, IID_GuiInterface);
+		cmpGuiInterface.PushNotification({"type": "diplomacy", "player": player, "player1": cmd.player, "status": cmd.to});
+		break;
+
+	case "tribute":
+		cmpPlayer.TributeResource(cmd.player, cmd.amounts);
+		break;
+
 	case "control-all":
 		cmpPlayer.SetControlAllUnits(cmd.flag);
 		break;
@@ -65,8 +88,15 @@ function ProcessCommand(player, cmd)
 		});
 		break;
 
+	case "attack-walk":
+		var entities = FilterEntityList(cmd.entities, player, controlAllUnits);
+		GetFormationUnitAIs(entities, player).forEach(function(cmpUnitAI) {
+			cmpUnitAI.WalkAndFight(cmd.x, cmd.z, cmd.queued);
+		});
+		break;
+
 	case "attack":
-		if (g_DebugCommands && !IsOwnedByEnemyOfPlayer(player, cmd.target))
+		if (g_DebugCommands && !(IsOwnedByEnemyOfPlayer(player, cmd.target) || IsOwnedByNeutralOfPlayer(player, cmd.target)))
 		{
 			// This check is for debugging only!
 			warn("Invalid command: attack target is not owned by enemy of player "+player+": "+uneval(cmd));
@@ -146,11 +176,30 @@ function ProcessCommand(player, cmd)
 
 	case "train":
 		var entities = FilterEntityList(cmd.entities, player, controlAllUnits);
+		
+		// Check entity limits
+		var cmpTempMan = Engine.QueryInterface(SYSTEM_ENTITY, IID_TemplateManager);
+		var template = cmpTempMan.GetTemplate(cmd.template);
+		var unitCategory = null;
+		if (template.TrainingRestrictions)
+			unitCategory = template.TrainingRestrictions.Category;
+
 		// Verify that the building(s) can be controlled by the player
 		if (entities.length > 0)
 		{
 			for each (var ent in entities)
 			{
+				if (unitCategory)
+				{
+					var cmpPlayerEntityLimits = QueryOwnerInterface(ent, IID_EntityLimits);
+					if (!cmpPlayerEntityLimits.AllowedToTrain(unitCategory, cmd.count))
+					{
+						if (g_DebugCommands)
+							warn(unitCategory + " train limit is reached: " + uneval(cmd));
+						continue;
+					}
+				}
+
 				var cmpTechnologyManager = QueryOwnerInterface(ent, IID_TechnologyManager);
 				// TODO: Enable this check once the AI gets technology support
 				if (cmpTechnologyManager.CanProduce(cmd.template) || true)
@@ -178,7 +227,7 @@ function ProcessCommand(player, cmd)
 		{
 			var cmpTechnologyManager = QueryOwnerInterface(cmd.entity, IID_TechnologyManager);
 			// TODO: Enable this check once the AI gets technology support
-			if (cmpTechnologyManager.CanResearch(cmd.template) || true)
+			if (cmpTechnologyManager.CanResearch(cmd.template) || cmpPlayer.IsAI())
 			{
 				var queue = Engine.QueryInterface(cmd.entity, IID_ProductionQueue);
 				if (queue)
@@ -270,7 +319,7 @@ function ProcessCommand(player, cmd)
 		{
 			var entities = FilterEntityList(cmd.entities, player, controlAllUnits);
 			GetFormationUnitAIs(entities, player).forEach(function(cmpUnitAI) {
-				cmpUnitAI.Garrison(cmd.target);
+				cmpUnitAI.Garrison(cmd.target, cmd.queued);
 			});
 		}
 		else if (g_DebugCommands)
@@ -328,11 +377,7 @@ function ProcessCommand(player, cmd)
 	case "formation":
 		var entities = FilterEntityList(cmd.entities, player, controlAllUnits);
 		GetFormationUnitAIs(entities, player, cmd.name).forEach(function(cmpUnitAI) {
-			var cmpFormation = Engine.QueryInterface(cmpUnitAI.entity, IID_Formation);
-			if (!cmpFormation)
-				return;
-			cmpFormation.LoadFormation(cmd.name);
-			cmpFormation.MoveMembersIntoFormation(true);
+			cmpUnitAI.MoveIntoFormation(cmd);
 		});
 		break;
 
@@ -415,6 +460,36 @@ function ProcessCommand(player, cmd)
 		}
 		break;
 
+	case "pack":
+		var entities = FilterEntityList(cmd.entities, player, controlAllUnits);
+		for each (var ent in entities)
+		{
+			var cmpUnitAI = Engine.QueryInterface(ent, IID_UnitAI);
+			if (cmpUnitAI)
+			{
+				if (cmd.pack)
+					cmpUnitAI.Pack(cmd.queued);
+				else
+					cmpUnitAI.Unpack(cmd.queued);
+			}
+		}
+		break;
+
+	case "cancel-pack":
+		var entities = FilterEntityList(cmd.entities, player, controlAllUnits);
+		for each (var ent in entities)
+		{
+			var cmpUnitAI = Engine.QueryInterface(ent, IID_UnitAI);
+			if (cmpUnitAI)
+			{
+				if (cmd.pack)
+					cmpUnitAI.CancelPack(cmd.queued);
+				else
+					cmpUnitAI.CancelUnpack(cmd.queued);
+			}
+		}
+		break;
+
 	default:
 		error("Invalid command: unknown command type: "+uneval(cmd));
 	}
@@ -457,6 +532,99 @@ function ExtractFormations(ents)
 	return { "entities": entities, "members": members, "ids": ids };
 }
 
+/**
+ * Tries to find the best angle to put a dock at a given position
+ * Taken from GuiInterface.js
+ */
+function GetDockAngle(templateName,x,y)
+{
+	var cmpTemplateMgr = Engine.QueryInterface(SYSTEM_ENTITY, IID_TemplateManager);
+	var template = cmpTemplateMgr.GetTemplate(templateName);
+
+	if (template.BuildRestrictions.Category !== "Dock")
+		return undefined;
+
+	var cmpTerrain = Engine.QueryInterface(SYSTEM_ENTITY, IID_Terrain);
+	var cmpWaterManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_WaterManager);
+	if (!cmpTerrain || !cmpWaterManager)
+	{
+		return undefined;
+	}
+	
+	// Get footprint size
+	var halfSize = 0;
+	if (template.Footprint.Square)
+	{
+		halfSize = Math.max(template.Footprint.Square["@depth"], template.Footprint.Square["@width"])/2;
+	}
+	else if (template.Footprint.Circle)
+	{
+		halfSize = template.Footprint.Circle["@radius"];
+	}
+	
+	/* Find direction of most open water, algorithm:
+	 *	1. Pick points in a circle around dock
+	 *	2. If point is in water, add to array
+	 *	3. Scan array looking for consecutive points
+	 *	4. Find longest sequence of consecutive points
+	 *	5. If sequence equals all points, no direction can be determined,
+	 *		expand search outward and try (1) again
+	 *	6. Calculate angle using average of sequence
+	 */
+	const numPoints = 16;
+	for (var dist = 0; dist < 4; ++dist)
+	{
+		var waterPoints = [];
+		for (var i = 0; i < numPoints; ++i)
+		{
+			var angle = (i/numPoints)*2*Math.PI;
+			var d = halfSize*(dist+1);
+			var nx = x - d*Math.sin(angle);
+			var nz = y + d*Math.cos(angle);
+			
+			if (cmpTerrain.GetGroundLevel(nx, nz) < cmpWaterManager.GetWaterLevel(nx, nz))
+			{
+				waterPoints.push(i);
+			}
+		}
+		var consec = [];
+		var length = waterPoints.length;
+		for (var i = 0; i < length; ++i)
+		{
+			var count = 0;
+			for (var j = 0; j < (length-1); ++j)
+			{
+				if (((waterPoints[(i + j) % length]+1) % numPoints) == waterPoints[(i + j + 1) % length])
+				{
+					++count;
+				}
+				else
+				{
+					break;
+				}
+			}
+			consec[i] = count;
+		}
+		var start = 0;
+		var count = 0;
+		for (var c in consec)
+		{
+			if (consec[c] > count)
+			{
+				start = c;
+				count = consec[c];
+			}
+		}
+		
+		// If we've found a shoreline, stop searching
+		if (count != numPoints-1)
+		{
+			return -(((waterPoints[start] + consec[start]/2) % numPoints)/numPoints*2*Math.PI);
+		}
+	}
+	return undefined;
+}
+
 /**
  * Attempts to construct a building using the specified parameters.
  * Returns true on success, false on failure.
@@ -471,6 +639,7 @@ function TryConstructBuilding(player, cmpPlayer, controlAllUnits, cmd)
 	//   "x": ...,
 	//   "z": ...,
 	//   "angle": ...,
+	//   "actorSeed": ...,
 	//   "autorepair": true,                // whether to automatically start constructing/repairing the new foundation
 	//   "autocontinue": true,              // whether to automatically gather/build/etc after finishing this
 	//   "queued": true,                    // whether to add the construction/repairing of this foundation to entities' queue (if applicable)
@@ -505,6 +674,11 @@ function TryConstructBuilding(player, cmpPlayer, controlAllUnits, cmd)
 		return false;
 	}
 	
+	// If it's a dock, get the right angle.
+	var angle = GetDockAngle(cmd.template,cmd.x,cmd.z);
+	if (angle !== undefined)
+		cmd.angle = angle;
+	
 	// Move the foundation to the right place
 	var cmpPosition = Engine.QueryInterface(ent, IID_Position);
 	cmpPosition.JumpTo(cmd.x, cmd.z);
@@ -528,34 +702,42 @@ function TryConstructBuilding(player, cmpPlayer, controlAllUnits, cmd)
 			cmpObstruction.SetControlGroup2(cmd.obstructionControlGroup2);
 	}
 	
-	// Check whether it's obstructed by other entities or invalid terrain
-	var cmpBuildRestrictions = Engine.QueryInterface(ent, IID_BuildRestrictions);
-	if (!cmpBuildRestrictions || !cmpBuildRestrictions.CheckPlacement(player))
-	{
-		if (g_DebugCommands)
-		{
-			warn("Invalid command: build restrictions check failed for player "+player+": "+uneval(cmd));
-		}
-		
-		var cmpGuiInterface = Engine.QueryInterface(SYSTEM_ENTITY, IID_GuiInterface);
-		cmpGuiInterface.PushNotification({ "player": player, "message": "Building site was obstructed" });
-		
-		// Remove the foundation because the construction was aborted
-		Engine.DestroyEntity(ent);
-		return false;
-	}
+	// Make it owned by the current player
+	var cmpOwnership = Engine.QueryInterface(ent, IID_Ownership);
+	cmpOwnership.SetOwner(player);
 	
-	// Check build limits
-	var cmpBuildLimits = QueryPlayerIDInterface(player, IID_BuildLimits);
-	if (!cmpBuildLimits || !cmpBuildLimits.AllowedToBuild(cmpBuildRestrictions.GetCategory()))
+	// Check whether building placement is valid
+	var cmpBuildRestrictions = Engine.QueryInterface(ent, IID_BuildRestrictions);
+	if (cmpBuildRestrictions)
+	{
+		var ret = cmpBuildRestrictions.CheckPlacement();
+		if (!ret.success)
+		{
+			if (g_DebugCommands)
+			{
+				warn("Invalid command: build restrictions check failed for player "+player+": "+uneval(cmd));
+			}
+
+			var cmpGuiInterface = Engine.QueryInterface(SYSTEM_ENTITY, IID_GuiInterface);
+			cmpGuiInterface.PushNotification({ "player": player, "message": ret.message });
+			
+			// Remove the foundation because the construction was aborted
+			Engine.DestroyEntity(ent);
+			return false;
+		}
+	}
+	else
+		error("cmpBuildRestrictions not defined");
+	
+	// Check entity limits
+	var cmpEntityLimits = QueryPlayerIDInterface(player, IID_EntityLimits);
+	if (!cmpEntityLimits || !cmpEntityLimits.AllowedToBuild(cmpBuildRestrictions.GetCategory()))
 	{
 		if (g_DebugCommands)
 		{
 			warn("Invalid command: build limits check failed for player "+player+": "+uneval(cmd));
 		}
-		
-		// TODO: The UI should tell the user they can't build this (but we still need this check)
-		
+
 		// Remove the foundation because the construction was aborted
 		Engine.DestroyEntity(ent);
 		return false;
@@ -564,7 +746,7 @@ function TryConstructBuilding(player, cmpPlayer, controlAllUnits, cmd)
 	var cmpTechnologyManager = QueryPlayerIDInterface(player, IID_TechnologyManager);
 	
 	// TODO: Enable this check once the AI gets technology support 
-	if (!cmpTechnologyManager.CanProduce(cmd.template) && false) 
+	if (!cmpTechnologyManager.CanProduce(cmd.template) && !cmpPlayer.IsAI()) 
 	{
 		if (g_DebugCommands)
 		{
@@ -576,29 +758,6 @@ function TryConstructBuilding(player, cmpPlayer, controlAllUnits, cmd)
 		
 		// Remove the foundation because the construction was aborted 
 		Engine.DestroyEntity(ent); 
-	} 
-	
-	// TODO: AI has no visibility info
-	if (!cmpPlayer.IsAI())
-	{
-		// Check whether it's in a visible or fogged region
-		//	tell GetLosVisibility to force RetainInFog because preview entities set this to false,
-		//	which would show them as hidden instead of fogged
-		var cmpRangeManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager);
-		var visible = (cmpRangeManager && cmpRangeManager.GetLosVisibility(ent, player, true) != "hidden");
-		if (!visible)
-		{
-			if (g_DebugCommands)
-			{
-				warn("Invalid command: foundation visibility check failed for player "+player+": "+uneval(cmd));
-			}
-			
-			var cmpGuiInterface = Engine.QueryInterface(SYSTEM_ENTITY, IID_GuiInterface);
-			cmpGuiInterface.PushNotification({ "player": player, "message": "Building site was not visible" });
-			
-			Engine.DestroyEntity(ent);
-			return false;
-		}
 	}
 	
 	// We need the cost after tech modifications
@@ -621,15 +780,15 @@ function TryConstructBuilding(player, cmpPlayer, controlAllUnits, cmd)
 		Engine.DestroyEntity(ent);
 		return false;
 	}
-	
-	// Make it owned by the current player
-	var cmpOwnership = Engine.QueryInterface(ent, IID_Ownership);
-	cmpOwnership.SetOwner(player);
-	
+
+	var cmpVisual = Engine.QueryInterface(ent, IID_Visual);
+	if (cmpVisual && cmd.actorSeed !== undefined)
+		cmpVisual.SetActorSeed(cmd.actorSeed);
+
 	// Initialise the foundation
 	var cmpFoundation = Engine.QueryInterface(ent, IID_Foundation);
 	cmpFoundation.InitialiseConstruction(player, cmd.template);
-	
+
 	// Tell the units to start building this new entity
 	if (cmd.autorepair)
 	{
@@ -641,7 +800,7 @@ function TryConstructBuilding(player, cmpPlayer, controlAllUnits, cmd)
 			"queued": cmd.queued
 		});
 	}
-	
+
 	return ent;
 }
 
@@ -743,7 +902,11 @@ function TryConstructWall(player, cmpPlayer, controlAllUnits, cmd)
 	for (; i < cmd.pieces.length; ++i)
 	{
 		var piece = cmd.pieces[i];
-		
+
+		// All wall pieces after the first must be queued.
+		if (i > 0 && !cmd.queued)
+			cmd.queued = true;
+
 		// 'lastTowerControlGroup' must always be defined and valid here, except if we're at the first piece and we didn't do
 		// start position snapping (implying that the first entity we build must be a tower)
 		if (lastTowerControlGroup === null || lastTowerControlGroup == INVALID_ENTITY)
