@@ -37,7 +37,9 @@ function LoadPlayerSettings(settings, newPlayers)
 			numPlayers = settings.PlayerData.length + 1;
 		}
 		else
+		{
 			warn("Player.js: Setup has no player data - using defaults");
+		}
 
 		for (var i = 0; i < numPlayers; ++i)
 		{
@@ -73,6 +75,11 @@ function LoadPlayerSettings(settings, newPlayers)
 			var colour = getSetting(pData, pDefs, "Colour");
 			cmpPlayer.SetColour(colour.r, colour.g, colour.b);
 
+			// Note: this is not yet implemented but I leave it commented to highlight it's easy
+			// If anyone ever adds handicap.
+			//if (getSetting(pData, pDefs, "GatherRateMultiplier") !== undefined)
+			//	cmpPlayer.SetGatherRateMultiplier(getSetting(pData, pDefs, "GatherRateMultiplier"));
+
 			if (getSetting(pData, pDefs, "PopulationLimit") !== undefined)
 				cmpPlayer.SetMaxPopulation(getSetting(pData, pDefs, "PopulationLimit"));
 
@@ -87,22 +94,16 @@ function LoadPlayerSettings(settings, newPlayers)
 				// Init diplomacy
 				cmpPlayer.SetDiplomacy(new Array(numPlayers));
 				var myTeam = getSetting(pData, pDefs, "Team");
-				cmpPlayer.SetTeam(myTeam);
+
+				// Set all but self as enemies as SetTeam takes care of allies
 				for (var j = 0; j < numPlayers; ++j)
 				{
-					if (j > 0)
-					{
-						// We are always our own ally, else check if player is on the same team
-						var theirTeam = getSetting(settings.PlayerData[j-1], playerDefaults[j], "Team");
-						if (i == j || (myTeam !== undefined && myTeam != -1 && theirTeam !== undefined && myTeam == theirTeam))
-						{
-							cmpPlayer.SetAlly(j);
-							continue;
-						}
-					}
-					// Gaia, different team, or no team defined
-					cmpPlayer.SetEnemy(j);
+					if (i == j)
+						cmpPlayer.SetAlly(j);
+					else
+						cmpPlayer.SetEnemy(j);
 				}
+				cmpPlayer.SetTeam((myTeam !== undefined) ? myTeam : -1);
 			}
 
 			// If formations explicitly defined, use that; otherwise use civ defaults
@@ -137,6 +138,15 @@ function LoadPlayerSettings(settings, newPlayers)
 				cmpPlayer.SetEnemy(j);
 		}
 	}
+
+	// NOTE: We need to do the team locking here, as otherwise
+	// SetTeam can't ally the players.
+	if (settings.LockTeams)
+		for (var i = 0; i < numPlayers; ++i)
+		{
+			var cmpPlayer = Engine.QueryInterface(cmpPlayerManager.GetPlayerByID(i), IID_Player);
+			cmpPlayer.SetLockTeams(true);
+		}
 }
 
 // Get a setting if it exists or return default
@@ -243,7 +253,6 @@ function IsOwnedByGaia(target)
  */
 function IsOwnedByAllyOfPlayer(player, target)
 {
-	// Figure out which player controls the foundation being built
 	var targetOwner = 0;
 	var cmpOwnershipTarget = Engine.QueryInterface(target, IID_Ownership);
 	if (cmpOwnershipTarget)
@@ -260,11 +269,10 @@ function IsOwnedByAllyOfPlayer(player, target)
 }
 
 /**
- * Returns true if the entity 'target' is owned by an enemy of player
+ * Returns true if the entity 'target' is owned by someone neutral to player
  */
-function IsOwnedByEnemyOfPlayer(player, target)
+function IsOwnedByNeutralOfPlayer(player,target)
 {
-	// Figure out which player controls the foundation being built
 	var targetOwner = 0;
 	var cmpOwnershipTarget = Engine.QueryInterface(target, IID_Ownership);
 	if (cmpOwnershipTarget)
@@ -273,7 +281,27 @@ function IsOwnedByEnemyOfPlayer(player, target)
 	var cmpPlayerManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_PlayerManager);
 	var cmpPlayer = Engine.QueryInterface(cmpPlayerManager.GetPlayerByID(player), IID_Player);
 
-	// Check for allied diplomacy status
+	// Check for neutral diplomacy status
+	if (cmpPlayer.IsNeutral(targetOwner))
+		return true;
+
+	return false;
+}
+
+/**
+ * Returns true if the entity 'target' is owned by an enemy of player
+ */
+function IsOwnedByEnemyOfPlayer(player, target)
+{
+	var targetOwner = 0;
+	var cmpOwnershipTarget = Engine.QueryInterface(target, IID_Ownership);
+	if (cmpOwnershipTarget)
+		targetOwner = cmpOwnershipTarget.GetOwner();
+
+	var cmpPlayerManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_PlayerManager);
+	var cmpPlayer = Engine.QueryInterface(cmpPlayerManager.GetPlayerByID(player), IID_Player);
+
+	// Check for enemy diplomacy status
 	if (cmpPlayer.IsEnemy(targetOwner))
 		return true;
 
@@ -287,4 +315,5 @@ Engine.RegisterGlobal("IsOwnedByAllyOfEntity", IsOwnedByAllyOfEntity);
 Engine.RegisterGlobal("IsOwnedByPlayer", IsOwnedByPlayer);
 Engine.RegisterGlobal("IsOwnedByGaia", IsOwnedByGaia);
 Engine.RegisterGlobal("IsOwnedByAllyOfPlayer", IsOwnedByAllyOfPlayer);
+Engine.RegisterGlobal("IsOwnedByNeutralOfPlayer", IsOwnedByNeutralOfPlayer);
 Engine.RegisterGlobal("IsOwnedByEnemyOfPlayer", IsOwnedByEnemyOfPlayer);
