@@ -3,7 +3,7 @@ var currentSubmenuType; // contains submenu type
 const MARGIN = 4; // menu border size
 const background = "hellenes1"; // Background type. Currently: 'hellenes1', 'persians1'.
 
-function init()
+function init(initData)
 {
 	initMusic();
 
@@ -16,6 +16,25 @@ function init()
 	currentSubmenuType = "submenuSinglePlayer";
 
 	EnableUserReport(Engine.IsUserReportEnabled());
+
+	// Only show splash screen(s) once
+	if (initData && initData.isStartup)
+	{
+		if (Engine.IsSplashScreenEnabled())
+			Engine.PushGuiPage("page_splashscreen.xml", { "page": "splashscreen" } );
+
+		// Warn about removing fixed render path
+		if (renderer.renderpath == "fixed")
+			messageBox(
+				600,
+				300,
+				"[font=\"serif-bold-16\"][color=\"200 20 20\"]Warning:[/color] You appear to be using non-shader (fixed function) graphics. This option will be removed in a future 0 A.D. release, to allow for more advanced graphics features. We advise upgrading your graphics card to a more recent, shader-compatible model.\n\nPlease press \"Read More\" for more information or \"Ok\" to continue.",
+				"WARNING!",
+				0,
+				["Ok", "Read More"],
+				[null, function() { Engine.OpenURL("http://www.wildfiregames.com/forum/index.php?showtopic=16734"); }]
+			);
+	}
 }
 
 var t0 = new Date;
