@@ -164,7 +164,7 @@ for (var i = 0; i < numPlayers; i++)
 		var aX = round(fx + aDist * cos(aAngle));
 		var aZ = round(fz + aDist * sin(aAngle));
 		var group = new SimpleGroup(
-			[new SimpleObject(oChicken, 5,5, 0,3)],
+			[new SimpleObject(oChicken, 5,5, 0,2)],
 			true, clBaseResource, aX, aZ
 		);
 		createObjectGroup(group, 0);
@@ -302,8 +302,7 @@ for (var m = 0; m < scaleByMapSize(1,3)*randInt(3,4); m++)
 	var elevationPainter = new SmoothElevationPainter(ELEVATION_SET, -4, 4);
 	createArea(placer, [painter, elevationPainter], avoidClasses(clPlayer, 15));
 }
-paintTerrainBasedOnHeight(3.1, 20, 0, tCliff);
-paintTerrainBasedOnHeight(20, 21, 1, tGrass);
+paintTerrainBasedOnHeight(3.1, 40, 0, tCliff);
 
 for (var i = 0; i < numPlayers; i++)
 {
@@ -573,10 +572,12 @@ setSkySet("sunny");
 }
 setSunRotation(randFloat(0, TWO_PI));
 setSunElevation(randFloat(PI/ 5, PI / 3));
-setWaterTint(0.447, 0.412, 0.322);				// muddy brown
-setWaterReflectionTint(0.447, 0.412, 0.322);	// muddy brown
-setWaterMurkiness(1.0);
-setWaterReflectionTintStrength(0.677);
+setWaterColour(0.0, 0.047, 0.286);				// dark majestic blue
+setWaterTint(0.471, 0.776, 0.863);				// light blue
+setWaterReflectionTint(0.0, 0.047, 0.286);
+setWaterMurkiness(0.72);
+setWaterWaviness(3);
+setWaterReflectionTintStrength(0.15);
 
 // Export map data
 
