@@ -342,7 +342,7 @@ for (var i = 0; i < numPlayers; i++)
 	for (var j = 0; j < 2; ++j)
 	{
 		var aAngle = randFloat(0, TWO_PI);
-		var aDist = 8;
+		var aDist = 7;
 		var aX = round(fx + aDist * cos(aAngle));
 		var aZ = round(fz + aDist * sin(aAngle));
 		var group = new SimpleGroup(
@@ -620,12 +620,12 @@ else
 	setSunRotation(2.3*PI/8);
 setTerrainAmbientColour(0.564706,0.543726,0.419608);
 setUnitsAmbientColour(0.53,0.55,0.45);
-setWaterColour(0.2, 0.35, 0.45);		
-setWaterTint(0.2, 0.6, 0.9);				
+setWaterColour(0.2,0.294,0.49);
+setWaterTint(0.208, 0.659, 0.925);
 setWaterReflectionTint(0.2, 0.6, 0.9);	
-setWaterMurkiness(0.78);
-setWaterReflectionTintStrength(0.377);
-setWaterWaviness(4);
+setWaterMurkiness(0.72);
+setWaterReflectionTintStrength(0.1);
+setWaterWaviness(4.5);
 // Export map data
 ExportMap();
 
