@@ -192,7 +192,7 @@ for (var i = 0; i < numPlayers; i++)
 		var aX = round(fx + aDist * cos(aAngle));
 		var aZ = round(fz + aDist * sin(aAngle));
 		var group = new SimpleGroup(
-			[new SimpleObject(oChicken, 5,5, 0,3)],
+			[new SimpleObject(oChicken, 5,5, 0,2)],
 			true, clBaseResource, aX, aZ
 		);
 		createObjectGroup(group, 0);
@@ -324,12 +324,6 @@ var terrainPainter = new LayeredPainter(
 	[tGrass, tGrass, tGrass, tGrass],		// terrains
 	[1, 4, 2]		// widths
 );
-var elevationPainter = new SmoothElevationPainter(
-	ELEVATION_SET,			// type
-	seaHeight,				// elevation
-	0				// blend radius
-);
-createArea(placer, [terrainPainter, elevationPainter, paintClass(clWater)], avoidClasses(clPlayer,scaleByMapSize(15,25)+4));
 var elevationPainter = new SmoothElevationPainter(
 	ELEVATION_SET,			// type
 	seaHeight,				// elevation
@@ -614,10 +608,13 @@ if (rt !== 3)
 setSkySet("stormy");
 setSunRotation(randFloat(0, TWO_PI));
 setSunElevation(randFloat(PI/ 5, PI / 3));
-setWaterTint(0.447, 0.412, 0.322);				// muddy brown
-setWaterReflectionTint(0.447, 0.412, 0.322);	// muddy brown
-setWaterMurkiness(1.0);
-setWaterReflectionTintStrength(0.677);
+
+setWaterColour(0.035,0.098,0.314);
+setWaterTint(0.259,0,49,0.808);
+setWaterReflectionTint(0.255, 0.361, 0.651);
+setWaterWaviness(3.0);
+setWaterMurkiness(0.88);
+setWaterReflectionTintStrength(0.05);
 
 // Export map data
 
