@@ -138,7 +138,7 @@ for (var i = 0; i < numPlayers; i++)
 		var aX = round(fx + aDist * cos(aAngle));
 		var aZ = round(fz + aDist * sin(aAngle));
 		var group = new SimpleGroup(
-			[new SimpleObject(oChicken, 5,5, 0,3)],
+			[new SimpleObject(oChicken, 5,5, 0,2)],
 			true, clBaseResource, aX, aZ
 		);
 		createObjectGroup(group, 0);
@@ -542,10 +542,12 @@ createObjectGroups(group, 0,
 
 // Set environment
 setSkySet("cirrus");
-setWaterTint(0.412, 0.412, 0.312);				
-setWaterReflectionTint(0.447, 0.402, 0.322);	
-setWaterMurkiness(1.0);
-setWaterReflectionTintStrength(0.677);
+setWaterColour(0.114, 0.192, 0.463);
+setWaterTint(0.255, 0.361, 0.651);
+setWaterReflectionTint(0.255, 0.361, 0.651);
+setWaterWaviness(5.5);
+setWaterMurkiness(0.83);
+setWaterReflectionTintStrength(0.05);
 
 // Export map data
 ExportMap();
