@@ -129,7 +129,7 @@ for (var i = 0; i < numPlayers; i++)
 		var aX = round(fx + aDist * cos(aAngle));
 		var aZ = round(fz + aDist * sin(aAngle));
 		var group = new SimpleGroup(
-			[new SimpleObject(oChicken, 5,5, 0,3)],
+			[new SimpleObject(oChicken, 5,5, 0,2)],
 			true, clBaseResource, aX, aZ
 		);
 		createObjectGroup(group, 0);
@@ -468,5 +468,12 @@ createObjectGroups(group, 0,
 	scaleByMapSize(16, 262)
 );
 
+setWaterColour(0, 0.227, 0.843);
+setWaterTint(0, 0.545, 0.859);
+setWaterReflectionTint(1, 1, 1);
+setWaterWaviness(1);
+setWaterMurkiness(0.75);
+setWaterReflectionTintStrength(0.0);
+
 // Export map data
 ExportMap();
