@@ -125,7 +125,7 @@ for (var i = 0; i < numPlayers; i++)
 		var aX = round(fx + aDist * cos(aAngle));
 		var aZ = round(fz + aDist * sin(aAngle));
 		var group = new SimpleGroup(
-			[new SimpleObject(oChicken, 5,5, 0,3)],
+			[new SimpleObject(oChicken, 5,5, 0,2)],
 			true, clBaseResource, aX, aZ
 		);
 		createObjectGroup(group, 0);
@@ -476,9 +476,11 @@ createObjectGroups(group, 0,
 
 // Set environment
 setSkySet("cirrus");
-setWaterTint(0.747, 0.712, 0.322);				// muddy brown
-setWaterReflectionTint(0.747, 0.712, 0.322);	// muddy brown
-setWaterMurkiness(1.0);
-setWaterReflectionTintStrength(0.377);
+setWaterColour(0.753,0.635,0.345);				// muddy brown
+setWaterTint(0.161,0.514,0.635);				// clear blue for blueness
+setWaterReflectionTint(0.561,0.435,0.196);		// muddy brown
+setWaterMurkiness(0.8);
+setWaterWaviness(0.8);
+setWaterReflectionTintStrength(0.4);
 
 ExportMap();
\ No newline at end of file
