@@ -55,6 +55,16 @@ function randomizeBiome()
 	biomeID = randInt(1,8);
 	//temperate
 	if (biomeID == 1){
+		
+		// temperate ocean blue, a bit too deep and saturated perhaps but it looks nicer.
+		// this assumes ocean settings, maps that aren't oceans should reset.
+		setWaterColour(0.114, 0.192, 0.463);
+		setWaterTint(0.255, 0.361, 0.651);
+		setWaterReflectionTint(0.255, 0.361, 0.651);
+		setWaterWaviness(5.5);
+		setWaterMurkiness(0.83);
+		setWaterReflectionTintStrength(0.05);
+		
 		rbt1 = ["temp_grass_long_b"];
 		rbt2 = "temp_forestfloor_pine";
 		rbt3 = "temp_plants_bog";
@@ -72,7 +82,10 @@ function randomizeBiome()
 		rbt15 = "medit_sand_wet";
 
 		// gaia entities
-		rbe1 = "gaia/flora_tree_oak";
+		if (randInt(1))
+			rbe1 = "gaia/flora_tree_oak";
+		else
+			rbe1 = "gaia/flora_tree_euro_beech";
 		rbe2 = "gaia/flora_tree_oak_large";
 		rbe3 = "gaia/flora_tree_apple";
 		rbe4 = "gaia/flora_tree_pine";
@@ -99,8 +112,16 @@ function randomizeBiome()
 		}
 	//snowy
 	else if (biomeID == 2)
-		{
+	{
 		setSunColour(0.550, 0.601, 0.644);				// a little darker
+		// Water is a semi-deep blue, fairly wavy, fairly murky for an ocean.
+		// this assumes ocean settings, maps that aren't oceans should reset.
+		setWaterColour(0.067, 0.212, 0.361);
+		setWaterTint(0.4, 0.486, 0.765);
+		setWaterReflectionTint(0.482, 0.824, 0.925);
+		setWaterWaviness(5.5);
+		setWaterMurkiness(0.83);
+		setWaterReflectionTintStrength(0.15);
 
 		rbt1 = ["polar_snow_b", "snow grass 75", "snow rocks", "snow forest"];
 		rbt2 = "polar_tundra_snow";
@@ -143,12 +164,22 @@ function randomizeBiome()
 		rba7 = "actor|props/flora/bush_desert_dry_a.xml";
 		rba8 = "actor|props/flora/bush_desert_dry_a.xml";
 		rba9 = "actor|flora/trees/pine_w.xml";
-		}
+			
+
+	}
 	//desert
 	else if (biomeID == 3)
-		{
+	{
 		setSunColour(0.733, 0.746, 0.574);	
 
+		// Went for a very clear, slightly blue-ish water in this case, basically no waves.
+		setWaterColour(0, 0.227, 0.843);
+		setWaterTint(0, 0.545, 0.859);
+		setWaterReflectionTint(1, 1, 1);
+		setWaterWaviness(1);
+		setWaterMurkiness(0.22);
+		setWaterReflectionTintStrength(0.0);
+		
 		rbt1 = ["desert_dirt_rough", "desert_dirt_rough_2", "desert_sand_dunes_50", "desert_sand_smooth"];
 		rbt2 = "forestfloor_dirty";
 		rbt3 = "desert_forestfloor_palms";
@@ -193,7 +224,16 @@ function randomizeBiome()
 	}
 	//alpine
 	else if (biomeID == 4)
-		{
+	{
+		// simulates an alpine lake, fairly deep.
+		// this is not intended for a clear running river, or even an ocean.
+		setWaterColour(0.0, 0.047, 0.286);				// dark majestic blue
+		setWaterTint(0.471, 0.776, 0.863);				// light blue
+		setWaterReflectionTint(0.0, 0.047, 0.286);
+		setWaterMurkiness(0.82);
+		setWaterWaviness(2);
+		setWaterReflectionTintStrength(0.15);
+
 		rbt1 = ["alpine_dirt_grass_50"];
 		rbt2 = "alpine_forrestfloor";
 		rbt3 = "alpine_forrestfloor";
@@ -237,7 +277,16 @@ function randomizeBiome()
 		rba9 = "actor|flora/trees/pine.xml";
 	}
 	//medit
-		else if (biomeID == 5){
+	else if (biomeID == 5)
+	{
+		// Guess what, this is based on the colors of the mediterranean sea.
+		setWaterColour(0.024,0.212,0.024);
+		setWaterTint(0.133, 0.725,0.855);
+		setWaterReflectionTint(0.31,0.769,0.894);
+		setWaterWaviness(3);
+		setWaterMurkiness(0.8);
+		setWaterReflectionTintStrength(0.1);
+
 		rbt1 = ["medit_grass_field_a", "medit_grass_field_b"];
 		rbt2 = "medit_plants_dirt";
 		rbt3 = "medit_grass_shrubs";
@@ -255,12 +304,18 @@ function randomizeBiome()
 		rbt15 = "medit_sand_wet";
 
 		// gaia entities
-		rbe1 = "gaia/flora_tree_cretan_date_palm_short";
+		if (randInt(1))
+			rbe1 = "gaia/flora_tree_cretan_date_palm_short";
+		else
+			rbe1 = "gaia/flora_tree_carob";
 		rbe2 = "gaia/flora_tree_medit_fan_palm";
 		rbe3 = "gaia/flora_tree_apple";
 		rbe4 = "gaia/flora_tree_cypress";
 		rbe5 = "gaia/flora_tree_aleppo_pine";
-		rbe6 = "gaia/flora_bush_berry";
+		if (randInt(1))
+			rbe6 = "gaia/flora_bush_berry";
+		else
+			rbe6 = "gaia/flora_bush_grapes";
 		rbe7 = "gaia/fauna_chicken";
 		rbe8 = "gaia/fauna_deer";
 		rbe9 = "gaia/fauna_fish";
@@ -282,7 +337,15 @@ function randomizeBiome()
 	}
 	//savanah
 	else if (biomeID == 6)
-		{
+	{
+		// Using the Malawi as a reference, in parts where it's not too murky from a river nearby.
+		setWaterColour(0.055,0.176,0.431);
+		setWaterTint(0.227,0.749,0.549);
+		setWaterReflectionTint(1,1,1);
+		setWaterWaviness(1.5);
+		setWaterMurkiness(0.77);
+		setWaterReflectionTintStrength(0.0);
+
 		rbt1 = ["savanna_grass_a", "savanna_grass_b"];
 		rbt2 = "savanna_forestfloor_a";
 		rbt3 = "savanna_forestfloor_b";
@@ -341,7 +404,18 @@ function randomizeBiome()
 		rba9 = "actor|flora/trees/baobab.xml";
 	}
 	//tropic
-	else if (biomeID == 7){
+	else if (biomeID == 7)
+	{
+		
+		// Bora-Bora ish. Quite transparent, not wavy.
+		// Mostly for shallow maps. Maps where the water level goes deeper should use a much darker Water Colour to simulate deep water holes.
+		setWaterColour(0.584,0.824,0.929);
+		setWaterTint(0.569,0.965,0.945);
+		setWaterReflectionTint(1,1,1);
+		setWaterWaviness(1.5);
+		setWaterMurkiness(0.35);
+		setWaterReflectionTintStrength(0.0);
+
 		rbt1 = ["tropic_grass_c", "tropic_grass_c", "tropic_grass_c", "tropic_grass_c", "tropic_grass_plants", "tropic_plants", "tropic_plants_b"];
 		rbt2 = "tropic_plants_c";
 		rbt3 = "tropic_plants_c";
@@ -386,7 +460,17 @@ function randomizeBiome()
 	}
 	//autumn
 	else if (biomeID == 8)
-		{
+	{
+			
+		// basically temperate with a reddish twist in the reflection and the tint. Also less wavy.
+		// this assumes ocean settings, maps that aren't oceans should reset.
+		setWaterColour(0.157, 0.149, 0.443);
+		setWaterTint(0.443,0.42,0.824);
+		setWaterReflectionTint(0.863,0.667,0.608);
+		setWaterWaviness(2.5);
+		setWaterMurkiness(0.83);
+		setWaterReflectionTintStrength(0.35);
+
 		rbt1 = ["temp_grass_aut", "temp_grass_aut", "temp_grass_d_aut"];
 		rbt2 = "temp_grass_aut";
 		rbt3 = "temp_grass_plants_aut";
@@ -428,7 +512,7 @@ function randomizeBiome()
 		rba7 = "actor|props/flora/bush_desert_dry_a.xml";
 		rba8 = "actor|props/flora/bush_desert_dry_a.xml";
 		rba9 = "actor|flora/trees/european_beech_aut.xml";
-		}
+	}
 	return biomeID;
 }
 
