@@ -132,7 +132,7 @@ for (var i = 0; i < numPlayers; i++)
 		var aX = round(fx + aDist * cos(aAngle));
 		var aZ = round(fz + aDist * sin(aAngle));
 		var group = new SimpleGroup(
-			[new SimpleObject(oChicken, 5,5, 0,3)],
+			[new SimpleObject(oChicken, 5,5, 0,2)],
 			true, clBaseResource, aX, aZ
 		);
 		createObjectGroup(group, 0);
@@ -555,10 +555,12 @@ setSkySet("sunny");
 
 setSunRotation(randFloat(0, TWO_PI));
 setSunElevation(randFloat(PI/ 5, PI / 4));
-setWaterTint(0.445, 0.410, 0.320);				// muddy brown
-setWaterReflectionTint(0.613, 0.445, 0.218);	// muddy brown
-setWaterMurkiness(0.3);
-setWaterReflectionTintStrength(0.455);
+setWaterColour(0.478,0.42,0.384);				// greyish
+setWaterTint(0.58,0.22,0.067);				// reddish
+setWaterReflectionTint(0.502,0.286,0.267);	// reddish
+setWaterMurkiness(0.87);
+setWaterWaviness(0.5);
+setWaterReflectionTintStrength(0.35);
 
 // Export map data
 
