@@ -27,6 +27,7 @@ const INPUT_BATCHTRAINING = 6;
 const INPUT_PRESELECTEDACTION = 7;
 const INPUT_BUILDING_WALL_CLICK = 8;
 const INPUT_BUILDING_WALL_PATHING = 9;
+const INPUT_MASSTRIBUTING = 10;
 
 var inputState = INPUT_NORMAL;
 var placementSupport = new PlacementSupport();
@@ -82,16 +83,20 @@ function updateCursorAndTooltip()
 	if (!tooltipSet)
 		informationTooltip.hidden = true;
 	
-	var wallDragTooltip = getGUIObjectByName("wallDragTooltip");
-	if (placementSupport.wallDragTooltip)
+	var placementTooltip = getGUIObjectByName("placementTooltip");
+	if (placementSupport.tooltipMessage)
 	{
-		wallDragTooltip.caption = placementSupport.wallDragTooltip;
-		wallDragTooltip.hidden = false;
+		if (placementSupport.tooltipError)
+			placementTooltip.sprite = "BackgroundErrorTooltip";
+		else
+			placementTooltip.sprite = "BackgroundInformationTooltip";
+		placementTooltip.caption = placementSupport.tooltipMessage;
+		placementTooltip.hidden = false;
 	}
 	else
 	{
-		wallDragTooltip.caption = "";
-		wallDragTooltip.hidden = true;
+		placementTooltip.caption = "";
+		placementTooltip.hidden = true;
 	}
 }
 
@@ -105,12 +110,18 @@ function updateBuildingPlacementPreview()
 	{
 		if (placementSupport.template && placementSupport.position)
 		{
-			return Engine.GuiInterfaceCall("SetBuildingPlacementPreview", {
+			var result = Engine.GuiInterfaceCall("SetBuildingPlacementPreview", {
 				"template": placementSupport.template,
 				"x": placementSupport.position.x,
 				"z": placementSupport.position.z,
 				"angle": placementSupport.angle,
+				"actorSeed": placementSupport.actorSeed
 			});
+
+			// Show placement info tooltip if invalid position
+			placementSupport.tooltipError = !result.success;
+			placementSupport.tooltipMessage = result.success ? "" : result.message;
+			return result.success;
 		}
 	}
 	else if (placementSupport.mode === "wall")
@@ -177,7 +188,7 @@ function getActionInfo(action, target)
 	{
 		if (action == "set-rallypoint" && haveRallyPoints)
 			return {"possible": true};
-		else if (action == "move")
+		else if (action == "move" || action == "attack-move")
 			return {"possible": true};
 		else
 			return {"possible": false};
@@ -286,6 +297,7 @@ function getActionInfo(action, target)
 		var playerState = simState.players[entState.player];
 		var playerOwned = (targetState.player == entState.player);
 		var allyOwned = playerState.isAlly[targetState.player];
+		var neutralOwned = playerState.isNeutral[targetState.player];
 		var enemyOwned = playerState.isEnemy[targetState.player];
 		var gaiaOwned = (targetState.player == 0);
 
@@ -321,20 +333,20 @@ function getActionInfo(action, target)
 				switch (tradingDetails.type)
 				{
 				case "is first":
-					tooltip = "First trade market.";
+					tooltip = "Origin trade market.";
 					if (tradingDetails.hasBothMarkets)
-						tooltip += " Gain: " + tradingDetails.gain + " " + tradingDetails.goods + ". Click to establish another route."
+						tooltip += " Gain: " + tradingDetails.gain + " " + tradingDetails.goods + ". Right-click to create a new trade route."
 					else
-						tooltip += " Click on another market to establish a trade route."
+						tooltip += " Right-click on another market to set it as a destination trade market."
 					break;
 				case "is second":
-					tooltip = "Second trade market. Gain: " + tradingDetails.gain + " " + tradingDetails.goods + "." + " Click to establish another route.";
+					tooltip = "Destination trade market. Gain: " + tradingDetails.gain + " " + tradingDetails.goods + "." + " Right-click to create a new trade route.";
 					break;
 				case "set first":
-					tooltip = "Set as first trade market";
+					tooltip = "Set as origin trade market";
 					break;
 				case "set second":
-					tooltip = "Set as second trade market. Gain: " + tradingDetails.gain + " " + tradingDetails.goods + ".";
+					tooltip = "Set as destination trade market. Gain: " + tradingDetails.gain + " " + tradingDetails.goods + ".";
 					break;
 				}
 				return {"possible": true, "tooltip": tooltip};
@@ -388,12 +400,12 @@ function getActionInfo(action, target)
 				return {"possible": true};
 			break;
 		case "attack":
-			if (entState.attack && targetState.hitpoints && enemyOwned)
+			if (entState.attack && targetState.hitpoints && (enemyOwned || neutralOwned))
 				return {"possible": Engine.GuiInterfaceCall("CanAttack", {"entity": entState.id, "target": target})};
 			break;
 		}
 	}
-	if (action == "move")
+	if (action == "move" || action == "attack-move")
 		return {"possible": true};
 	else
 		return {"possible": false};
@@ -465,12 +477,17 @@ function determineAction(x, y, fromMinimap)
 			break;
 		}
 	}
-	else if (Engine.HotkeyIsPressed("session.garrison"))
+	else if (Engine.HotkeyIsPressed("session.attack") && getActionInfo("attack", target).possible)
 	{
-		if (getActionInfo("garrison", target).possible)
-			return {"type": "garrison", "cursor": "action-garrison", "target": target};
-		else
-			return 	{"type": "none", "cursor": "action-garrison-disabled", "target": undefined};
+		return {"type": "attack", "cursor": "action-attack", "target": target};
+	}
+	else if (Engine.HotkeyIsPressed("session.garrison") && getActionInfo("garrison", target).possible)
+	{
+		return {"type": "garrison", "cursor": "action-garrison", "target": target};
+	}
+	else if (Engine.HotkeyIsPressed("session.attackmove") && getActionInfo("attack-move", target).possible)
+	{
+			return {"type": "attack-move", "cursor": "action-attack-move"};
 	}
 	else
 	{
@@ -509,7 +526,7 @@ function tryPlaceBuilding(queued)
 		error("[tryPlaceBuilding] Called while in '"+placementSupport.mode+"' placement mode instead of 'building'");
 		return false;
 	}
-	
+
 	var selection = g_Selection.toList();
 
 	// Use the preview to check it's a valid build location
@@ -527,6 +544,7 @@ function tryPlaceBuilding(queued)
 		"x": placementSupport.position.x,
 		"z": placementSupport.position.z,
 		"angle": placementSupport.angle,
+		"actorSeed": placementSupport.actorSeed,
 		"entities": selection,
 		"autorepair": true,
 		"autocontinue": true,
@@ -536,11 +554,13 @@ function tryPlaceBuilding(queued)
 
 	if (!queued)
 		placementSupport.Reset();
+	else
+		placementSupport.RandomizeActorSeed();
 
 	return true;
 }
 
-function tryPlaceWall()
+function tryPlaceWall(queued)
 {
 	if (placementSupport.mode !== "wall")
 	{
@@ -563,7 +583,7 @@ function tryPlaceWall()
 		"type": "construct-wall",
 		"autorepair": true,
 		"autocontinue": true,
-		"queued": true,
+		"queued": queued,
 		"entities": selection,
 		"wallSet": placementSupport.wallSet,
 		"pieces": wallPlacementInfo.pieces,
@@ -853,10 +873,10 @@ function handleInputBeforeGui(ev, hoveredObject)
 				
 				if (result && result.cost)
 				{
-					placementSupport.wallDragTooltip = getEntityCostTooltip(result);
+					placementSupport.tooltipMessage = getEntityCostTooltip(result);
 					var neededResources = Engine.GuiInterfaceCall("GetNeededResources", result.cost);
 					if (neededResources)
-						placementSupport.wallDragTooltip += getNeededResourcesTooltip(neededResources);
+						placementSupport.tooltipMessage += getNeededResourcesTooltip(neededResources);
 				}
 				
 				break;
@@ -864,25 +884,26 @@ function handleInputBeforeGui(ev, hoveredObject)
 			case "mousebuttondown":
 				if (ev.button == SDL_BUTTON_LEFT)
 				{
-					if (tryPlaceWall())
+					var queued = Engine.HotkeyIsPressed("session.queue");
+					if (tryPlaceWall(queued))
 					{
-    					if (Engine.HotkeyIsPressed("session.queue"))
-    					{
-    						// continue building, just set a new starting position where we left off
-    						placementSupport.position = placementSupport.wallEndPosition;
-    						placementSupport.wallEndPosition = undefined;
-    						
-    						inputState = INPUT_BUILDING_WALL_CLICK;
-    					}
-    					else
-    					{
-    						placementSupport.Reset();
-    						inputState = INPUT_NORMAL;
-    					}
+						if (queued)
+						{
+							// continue building, just set a new starting position where we left off
+							placementSupport.position = placementSupport.wallEndPosition;
+							placementSupport.wallEndPosition = undefined;
+							
+							inputState = INPUT_BUILDING_WALL_CLICK;
+						}
+						else
+						{
+							placementSupport.Reset();
+							inputState = INPUT_NORMAL;
+						}
 					}
 					else
 					{
-						placementSupport.wallDragTooltip = "Cannot build wall here!";
+						placementSupport.tooltipMessage = "Cannot build wall here!";
 					}
 					
 					updateBuildingPlacementPreview();
@@ -967,17 +988,21 @@ function handleInputBeforeGui(ev, hoveredObject)
 		}
 		break;
 
-	case INPUT_BATCHTRAINING:
-		switch (ev.type)
+	case INPUT_MASSTRIBUTING:
+		if (ev.type == "hotkeyup" && ev.hotkey == "session.masstribute")
 		{
-		case "hotkeyup":
-			if (ev.hotkey == "session.batchtrain")
-			{
-				flushTrainingBatch();
-				inputState = INPUT_NORMAL;
-			}
-			break;
+			flushTributing();
+			inputState = INPUT_NORMAL;
 		}
+		break;
+
+	case INPUT_BATCHTRAINING:
+		if (ev.type == "hotkeyup" && ev.hotkey == "session.batchtrain")
+		{
+			flushTrainingBatch();
+			inputState = INPUT_NORMAL;
+		}
+		break;
 	}
 
 	return false;
@@ -1301,6 +1326,12 @@ function doAction(action, ev)
 		Engine.GuiInterfaceCall("PlaySound", { "name": "order_walk", "entity": selection[0] });
 		return true;
 
+	case "attack-move":
+		var target = Engine.GetTerrainAtScreenPoint(ev.x, ev.y);
+		Engine.PostNetworkCommand({"type": "attack-walk", "entities": selection, "x": target.x, "z": target.z, "queued": queued});
+		Engine.GuiInterfaceCall("PlaySound", { "name": "order_walk", "entity": selection[0] });
+		return true;
+
 	case "attack":
 		Engine.PostNetworkCommand({"type": "attack", "entities": selection, "target": action.target, "queued": queued});
 		Engine.GuiInterfaceCall("PlaySound", { "name": "order_attack", "entity": selection[0] });
@@ -1400,6 +1431,11 @@ function handleMinimapEvent(target)
 			Engine.GuiInterfaceCall("PlaySound", { "name": "order_walk", "entity": selection[0] });
 			return true;
 
+		case "attack-move":
+			Engine.PostNetworkCommand({"type": "attack-walk", "entities": selection, "x": target.x, "z": target.z, "queued": queued});
+			Engine.GuiInterfaceCall("PlaySound", { "name": "order_walk", "entity": selection[0] });
+			return true;
+
 		case "set-rallypoint":
 			Engine.PostNetworkCommand({"type": "set-rallypoint", "entities": selection, "x": target.x, "z": target.z});
 			// Display rally point at the new coordinates, to avoid display lag
@@ -1461,17 +1497,102 @@ function exchangeResources(command)
 var batchTrainingEntities;
 var batchTrainingType;
 var batchTrainingCount;
+var batchTrainingEntityAllowedCount;
 const batchIncrementSize = 5;
 
 function flushTrainingBatch()
 {
-	Engine.PostNetworkCommand({"type": "train", "entities": batchTrainingEntities, "template": batchTrainingType, "count": batchTrainingCount});
+	var appropriateBuildings = getBuildingsWhichCanTrainEntity(batchTrainingEntities, batchTrainingType);
+	// If training limits don't allow us to train batchTrainingCount in each appropriate building
+	if (batchTrainingEntityAllowedCount !== undefined &&
+		batchTrainingEntityAllowedCount < batchTrainingCount * appropriateBuildings.length)
+	{
+		// Train as many full batches as we can
+		var buildingsCountToTrainFullBatch = Math.floor(batchTrainingEntityAllowedCount / batchTrainingCount);
+		var buildingsToTrainFullBatch = appropriateBuildings.slice(0, buildingsCountToTrainFullBatch);
+		Engine.PostNetworkCommand({"type": "train", "entities": buildingsToTrainFullBatch,
+			"template": batchTrainingType, "count": batchTrainingCount});
+
+		// Train remainer in one more building
+		var remainderToTrain = batchTrainingEntityAllowedCount % batchTrainingCount;
+		Engine.PostNetworkCommand({"type": "train",
+			"entities": [ appropriateBuildings[buildingsCountToTrainFullBatch] ],
+			"template": batchTrainingType, "count": remainderToTrain});
+	}
+	else
+	{
+		Engine.PostNetworkCommand({"type": "train", "entities": appropriateBuildings,
+			"template": batchTrainingType, "count": batchTrainingCount});
+	}
+}
+
+function getBuildingsWhichCanTrainEntity(entitiesToCheck, trainEntType)
+{
+	return entitiesToCheck.filter(function(entity) {
+		var state = GetEntityState(entity);
+		var canTrain = state && state.production && state.production.entities.length &&
+			state.production.entities.indexOf(trainEntType) != -1;
+		return canTrain;
+	});
+}
+
+function getEntityLimitAndCount(playerState, entType)
+{
+	var template = GetTemplateData(entType);
+	var trainingCategory = null;
+	if (template.trainingRestrictions)
+		trainingCategory = template.trainingRestrictions.category;
+	var trainEntLimit = undefined;
+	var trainEntCount = undefined;
+	var canBeTrainedCount = undefined;
+	if (trainingCategory && playerState.entityLimits[trainingCategory])
+	{
+		trainEntLimit = playerState.entityLimits[trainingCategory];
+		trainEntCount = playerState.entityCounts[trainingCategory];
+		canBeTrainedCount = Math.max(trainEntLimit - trainEntCount, 0);
+	}
+	return [trainEntLimit, trainEntCount, canBeTrainedCount];
+}
+
+// Add the unit shown at position to the training queue for all entities in the selection
+function addTrainingByPosition(position)
+{
+	var simState = Engine.GuiInterfaceCall("GetSimulationState");
+	var playerState = simState.players[Engine.GetPlayerID()];
+	var selection = g_Selection.toList();
+
+	if (!selection.length)
+		return;
+	
+	var trainableEnts = getAllTrainableEntities(selection);
+	
+	// Check if the position is valid
+	if (!trainableEnts.length || trainableEnts.length <= position) 
+		return;
+	
+	var entToTrain = trainableEnts[position];
+	
+	addTrainingToQueue(selection, entToTrain, playerState);
+	return;
 }
 
 // Called by GUI when user clicks training button
-function addTrainingToQueue(selection, trainEntType)
+function addTrainingToQueue(selection, trainEntType, playerState)
 {
-	if (Engine.HotkeyIsPressed("session.batchtrain"))
+	// Create list of buildings which can train trainEntType
+	var appropriateBuildings = getBuildingsWhichCanTrainEntity(selection, trainEntType);
+
+	// Check trainEntType entity limit and count
+	var [trainEntLimit, trainEntCount, canBeTrainedCount] = getEntityLimitAndCount(playerState, trainEntType)
+
+	// Batch training possible if we can train at least 2 units
+	var batchTrainingPossible = canBeTrainedCount == undefined || canBeTrainedCount > 1;
+
+	var decrement = Engine.HotkeyIsPressed("selection.remove");
+	if (!decrement)
+		var template = GetTemplateData(trainEntType);
+
+	if (Engine.HotkeyIsPressed("session.batchtrain") && batchTrainingPossible)
 	{
 		if (inputState == INPUT_BATCHTRAINING)
 		{
@@ -1488,27 +1609,55 @@ function addTrainingToQueue(selection, trainEntType)
 				}
 			}
 			// If we're already creating a batch of this unit (in the same building(s)), then just extend it
+			// (if training limits allow)
 			if (sameEnts && batchTrainingType == trainEntType)
 			{
-				batchTrainingCount += batchIncrementSize;
+				if (decrement)
+				{
+					batchTrainingCount -= batchIncrementSize;
+					if (batchTrainingCount <= 0)
+						inputState = INPUT_NORMAL;
+				}
+				else if (canBeTrainedCount == undefined ||
+					canBeTrainedCount > batchTrainingCount * appropriateBuildings.length)
+				{
+					if (Engine.GuiInterfaceCall("GetNeededResources", multiplyEntityCosts(
+						template, batchTrainingCount + batchIncrementSize)))
+						return;
+
+					batchTrainingCount += batchIncrementSize;
+				}
+				batchTrainingEntityAllowedCount = canBeTrainedCount;
 				return;
 			}
 			// Otherwise start a new one
-			else
+			else if (!decrement)
 			{
 				flushTrainingBatch();
 				// fall through to create the new batch
 			}
 		}
+
+		// Don't start a new batch if decrementing or unable to afford it.
+		if (decrement || Engine.GuiInterfaceCall("GetNeededResources",
+			multiplyEntityCosts(template, batchIncrementSize)))
+			return;
+
 		inputState = INPUT_BATCHTRAINING;
 		batchTrainingEntities = selection;
 		batchTrainingType = trainEntType;
+		batchTrainingEntityAllowedCount = canBeTrainedCount;
 		batchTrainingCount = batchIncrementSize;
 	}
 	else
 	{
-		// Non-batched - just create a single entity
-		Engine.PostNetworkCommand({"type": "train", "template": trainEntType, "count": 1, "entities": selection});
+		// Non-batched - just create a single entity in each building
+		// (but no more than entity limit allows)
+		var buildingsForTraining = appropriateBuildings;
+		if (trainEntLimit)
+			buildingsForTraining = buildingsForTraining.slice(0, canBeTrainedCount);
+		Engine.PostNetworkCommand({"type": "train", "template": trainEntType,
+			"count": 1, "entities": buildingsForTraining});
 	}
 }
 
@@ -1520,12 +1669,42 @@ function addResearchToQueue(entity, researchType)
 
 // Returns the number of units that will be present in a batch if the user clicks
 // the training button with shift down
-function getTrainingBatchStatus(entity, trainEntType)
+function getTrainingBatchStatus(playerState, entity, trainEntType, selection)
 {
-	if (inputState == INPUT_BATCHTRAINING && batchTrainingEntities.indexOf(entity) != -1 && batchTrainingType == trainEntType)
-		return [batchTrainingCount, batchIncrementSize];
+	var appropriateBuildings = [entity];
+	if (selection && selection.indexOf(entity) != -1)
+		appropriateBuildings = getBuildingsWhichCanTrainEntity(selection, trainEntType);
+	var nextBatchTrainingCount = 0;
+	var currentBatchTrainingCount = 0;
+
+	if (inputState == INPUT_BATCHTRAINING && batchTrainingEntities.indexOf(entity) != -1 &&
+		batchTrainingType == trainEntType)
+	{
+		nextBatchTrainingCount = batchTrainingCount;
+		currentBatchTrainingCount = batchTrainingCount;
+		var canBeTrainedCount = batchTrainingEntityAllowedCount;
+	}
 	else
-		return [0, batchIncrementSize];
+	{
+		var [trainEntLimit, trainEntCount, canBeTrainedCount] =
+			getEntityLimitAndCount(playerState, trainEntType);
+		var batchSize = Math.min(canBeTrainedCount, batchIncrementSize);
+	}
+	// We need to calculate count after the next increment if it's possible
+	if (canBeTrainedCount == undefined ||
+		canBeTrainedCount > nextBatchTrainingCount * appropriateBuildings.length)
+		nextBatchTrainingCount += batchIncrementSize;
+	// If training limits don't allow us to train batchTrainingCount in each appropriate building
+	// train as many full batches as we can and remainer in one more building.
+	var buildingsCountToTrainFullBatch = appropriateBuildings.length;
+	var remainderToTrain = 0;
+	if (canBeTrainedCount !== undefined &&
+		canBeTrainedCount < nextBatchTrainingCount * appropriateBuildings.length)
+	{
+		buildingsCountToTrainFullBatch = Math.floor(canBeTrainedCount / nextBatchTrainingCount);
+		remainderToTrain = canBeTrainedCount % nextBatchTrainingCount;
+	}
+	return [buildingsCountToTrainFullBatch, nextBatchTrainingCount, remainderToTrain, currentBatchTrainingCount];
 }
 
 // Called by GUI when user clicks production queue item
@@ -1535,9 +1714,9 @@ function removeFromProductionQueue(entity, id)
 }
 
 // Called by unit selection buttons
-function changePrimarySelectionGroup(templateName)
+function changePrimarySelectionGroup(templateName, deselectGroup)
 {
-	if (Engine.HotkeyIsPressed("session.deselectgroup"))
+	if (Engine.HotkeyIsPressed("session.deselectgroup") || deselectGroup)
 		g_Selection.makePrimarySelection(templateName, true);
 	else
 		g_Selection.makePrimarySelection(templateName, false);
@@ -1673,6 +1852,30 @@ function lockGate(lock)
 	});
 }
 
+// Pack / unpack unit(s)
+function packUnit(pack)
+{
+	var selection = g_Selection.toList();
+	Engine.PostNetworkCommand({
+		"type": "pack",
+		"entities": selection,
+		"pack": pack,
+		"queued": false
+	});
+}
+
+// Cancel un/packing unit(s)
+function cancelPackUnit(pack)
+{
+	var selection = g_Selection.toList();
+	Engine.PostNetworkCommand({
+		"type": "cancel-pack",
+		"entities": selection,
+		"pack": pack,
+		"queued": false
+	});
+}
+
 // Transform a wall to a gate
 function transformWallToGate(template)
 {
@@ -1716,30 +1919,58 @@ function setCameraFollow(entity)
 
 var lastIdleUnit = 0;
 var currIdleClass = 0;
+var lastIdleType = undefined;
 
 function resetIdleUnit()
 {
 	lastIdleUnit = 0;
 	currIdleClass = 0;
+	lastIdleType = undefined;
 }
 
 function findIdleUnit(classes)
 {
-	// Cycle through idling classes before giving up
-	for (var i = 0; i <= classes.length; ++i)
+	var append = Engine.HotkeyIsPressed("selection.add");
+	var selectall = Engine.HotkeyIsPressed("selection.offscreen");
+
+	// Reset the last idle unit, etc., if the selection type has changed.
+	var type = classes.join();
+	if (selectall || type != lastIdleType)
+		resetIdleUnit();
+	lastIdleType = type;
+
+	// If selectall is true, there is no limit and it's necessary to iterate
+	// over all of the classes, resetting only when the first match is found.
+	var matched = false;
+
+	for (var i = 0; i < classes.length; ++i)
 	{
-		var data = { prevUnit: lastIdleUnit, idleClass: classes[currIdleClass] };
-		var newIdleUnit = Engine.GuiInterfaceCall("FindIdleUnit", data);
+		var data = { idleClass: classes[currIdleClass], prevUnit: lastIdleUnit, limit: 1 };
+		if (append)
+			data.excludeUnits = g_Selection.toList();
+
+		if (selectall)
+			data = { idleClass: classes[currIdleClass] };
 
 		// Check if we have new valid entity
-		if (newIdleUnit && newIdleUnit != lastIdleUnit)
+		var idleUnits = Engine.GuiInterfaceCall("FindIdleUnits", data);
+		if (idleUnits.length && idleUnits[0] != lastIdleUnit)
 		{
-			lastIdleUnit = newIdleUnit;
-			g_Selection.reset()
-			g_Selection.addList([lastIdleUnit]);
-			Engine.CameraFollow(lastIdleUnit);
+			lastIdleUnit = idleUnits[0];
+			if (!append && (!selectall || selectall && !matched))
+				g_Selection.reset()
 
-			return;
+			if (selectall)
+				g_Selection.addList(idleUnits);
+			else
+			{
+				g_Selection.addList([lastIdleUnit]);
+				var position = GetEntityState(lastIdleUnit).position;
+				Engine.CameraMoveTo(position.x, position.z);
+				return;
+			}
+
+			matched = true;
 		}
 
 		lastIdleUnit = 0;
