@@ -22,11 +22,22 @@ function handleNotifications()
 	// Handle chat notifications specially
 	if (notification.type == "chat")
 	{
-		addChatMessage({
-			"type": "message",
-			"guid": findGuidForPlayerID(g_PlayerAssignments, notification.player),
-			"text": notification.message
-		});
+		var guid = findGuidForPlayerID(g_PlayerAssignments, notification.player);
+		if (guid == undefined)
+		{
+			addChatMessage({
+				"type": "message",
+				"guid": -1,
+				"player": notification.player,
+				"text": notification.message
+			});
+		} else {
+			addChatMessage({
+				"type": "message",
+				"guid": findGuidForPlayerID(g_PlayerAssignments, notification.player),
+				"text": notification.message
+			});
+		}
 	}
 	else if (notification.type == "defeat")
 	{
@@ -35,12 +46,38 @@ function handleNotifications()
 			"guid": findGuidForPlayerID(g_PlayerAssignments, notification.player),
 			"player": notification.player
 		});
+
+		// If the diplomacy panel is open refresh it.
+		if (isDiplomacyOpen)
+			openDiplomacy();
+	}
+	else if (notification.type == "diplomacy")
+	{
+		addChatMessage({
+			"type": "diplomacy",
+			"player": notification.player,
+			"player1": notification.player1,
+			"status": notification.status
+		});
+
+		// If the diplomacy panel is open refresh it.
+		if (isDiplomacyOpen)
+			openDiplomacy();
 	}
 	else if (notification.type == "quit")
 	{
 		// Used for AI testing
 		exit();
 	}
+	else if (notification.type == "tribute")
+	{
+		addChatMessage({
+			"type": "tribute",
+			"player": notification.player,
+			"player1": notification.player1,
+			"amounts": notification.amounts
+		});
+	}
 	else
 	{
 		// Only display notifications directed to this player
@@ -81,6 +118,10 @@ function handleNetMessage(message)
 	switch (message.type)
 	{
 	case "netstatus":
+		// If we lost connection, further netstatus messages are useless
+		if (g_Disconnected)
+			return;
+
 		var obj = getGUIObjectByName("netStatus");
 		switch (message.status)
 		{
@@ -105,9 +146,9 @@ function handleNetMessage(message)
 			obj.hidden = false;
 			break;
 		case "disconnected":
+			g_Disconnected = true;
 			obj.caption = "Connection to the server has been lost.\n\nThe game has ended.";
 			obj.hidden = false;
-			getGUIObjectByName("disconnectedExitButton").hidden = false;
 			break;
 		default:
 			error("Unrecognised netstatus type "+message.status);
@@ -248,6 +289,12 @@ function addChatMessage(msg, playerAssignments)
 		// This case is hit for AIs, whose names don't exist in playerAssignments.
 		playerColor = g_Players[msg.player].color.r + " " + g_Players[msg.player].color.g + " " + g_Players[msg.player].color.b;
 		username = escapeText(g_Players[msg.player].name);
+	} else if (msg.type == "message")
+	{
+		// This case is hit for AIs, whose names don't exist in playerAssignments.
+		playerColor = g_Players[msg.player].color.r + " " + g_Players[msg.player].color.g + " " + g_Players[msg.player].color.b;
+		username = escapeText(g_Players[msg.player].name);
+		parseChatCommands(msg, playerAssignments);
 	}
 	else
 	{
@@ -272,6 +319,43 @@ function addChatMessage(msg, playerAssignments)
 		var verb = (!g_IsNetworked && msg.player == Engine.GetPlayerID()) ? "have" : "has";
 		formatted = "[color=\"" + playerColor + "\"]" + username + "[/color] " + verb + " been defeated.";
 		break;
+	case "diplomacy":
+		var status = (msg.status == "ally" ? "allied" : (msg.status == "enemy" ? "at war" : "neutral"));
+		if (msg.player == Engine.GetPlayerID())
+		{
+			username= escapeText(g_Players[msg.player1].name);
+			playerColor = g_Players[msg.player1].color.r + " " + g_Players[msg.player1].color.g + " " + g_Players[msg.player1].color.b;
+			formatted = "You are now "+status+" with [color=\"" + playerColor + "\"]"+username + "[/color].";
+		}
+		else if (msg.player1 == Engine.GetPlayerID())
+		{
+			username= escapeText(g_Players[msg.player].name);
+			playerColor = g_Players[msg.player].color.r + " " + g_Players[msg.player].color.g + " " + g_Players[msg.player].color.b;
+			formatted = "[color=\"" + playerColor + "\"]" + username + "[/color] is now " + status + " with you."
+		}
+		else // No need for other players to know of this.
+			return;
+		break;
+	case "tribute":
+		if (msg.player != Engine.GetPlayerID()) 
+			return;
+
+		username = escapeText(g_Players[msg.player1].name);
+		playerColor = g_Players[msg.player1].color.r + " " + g_Players[msg.player1].color.g + " " + g_Players[msg.player1].color.b;
+
+		// Format the amounts to proper English: 200 food, 100 wood, and 300 metal; 100 food; 400 wood and 200 stone
+		var amounts = Object.keys(msg.amounts)
+			.filter(function (type) { return msg.amounts[type] > 0; })
+			.map(function (type) { return msg.amounts[type] + " " + type; });
+
+		if (amounts.length > 1)
+		{
+			var lastAmount = amounts.pop();
+			amounts = amounts.join(", ") + " and " + lastAmount;
+		}
+
+		formatted = "[color=\"" + playerColor + "\"]" + username + "[/color] has sent you " + amounts + ".";
+		break;
 	case "message":
 		// May have been hidden by the 'team' command.
 		if (msg.hide)
@@ -317,7 +401,12 @@ function parseChatCommands(msg, playerAssignments)
 	if (!msg.text || msg.text[0] != '/')
 		return;
 
-	var sender = playerAssignments[msg.guid].player;
+	var sender;
+	if (playerAssignments[msg.guid])
+		sender = playerAssignments[msg.guid].player;
+	else
+		sender = msg.player;
+	
 	var recurse = false;
 	var split = msg.text.split(/\s/);
 
@@ -338,6 +427,8 @@ function parseChatCommands(msg, playerAssignments)
 					msg.hide = true;
 				else
 					msg.prefix = "(Team) ";
+			} else {
+				msg.hide = true;
 			}
 			recurse = true;
 			break;
@@ -365,7 +456,7 @@ function parseChatCommands(msg, playerAssignments)
 					matched = player.name;
 
 			// If the local player's name was the longest one matched, show the message.
-			var playerName = g_Players[Engine.GetPlayerID()].name;			
+			var playerName = g_Players[Engine.GetPlayerID()].name;
 			if (matched.length && (matched == playerName || sender == Engine.GetPlayerID()))
 			{
 				msg.prefix = "(Private) ";
