@@ -10,6 +10,7 @@ const TRADING = "Trading";
 const COMMAND = "Command";
 const STANCE = "Stance";
 const GATE = "Gate";
+const PACK = "Pack";
 
 // Constants
 const COMMANDS_PANEL_WIDTH = 228;
@@ -29,10 +30,10 @@ const BARTER_ACTIONS = ["Sell", "Buy"];
 const GATE_ACTIONS = ["Lock", "Unlock"];
 
 // The number of currently visible buttons (used to optimise showing/hiding)
-var g_unitPanelButtons = {"Selection": 0, "Queue": 0, "Formation": 0, "Garrison": 0, "Training": 0, "Research": 0, "Barter": 0, "Trading": 0, "Construction": 0, "Command": 0, "Stance": 0, "Gate": 0};
+var g_unitPanelButtons = {"Selection": 0, "Queue": 0, "Formation": 0, "Garrison": 0, "Training": 0, "Research": 0, "Barter": 0, "Trading": 0, "Construction": 0, "Command": 0, "Stance": 0, "Gate": 0, "Pack": 0};
 
 // Unit panels are panels with row(s) of buttons
-var g_unitPanels = ["Selection", "Queue", "Formation", "Garrison", "Training", "Barter", "Trading", "Construction", "Research", "Stance", "Command", "Gate"];
+var g_unitPanels = ["Selection", "Queue", "Formation", "Garrison", "Training", "Barter", "Trading", "Construction", "Research", "Stance", "Command", "Gate", "Pack"];
 
 // Indexes of resources to sell and buy on barter panel
 var g_barterSell = 0;
@@ -138,6 +139,62 @@ function setOverlay(object, value)
 	object.hidden = !value;
 }
 
+/**
+ * Format entity count/limit message for the tooltip
+ */
+function formatLimitString(trainEntLimit, trainEntCount)
+{
+	if (trainEntLimit == undefined)
+		return "";
+	var text = "\n\nCurrent count: " + trainEntCount + ", limit: " + trainEntLimit + ".";
+	if (trainEntCount >= trainEntLimit)
+		text = "[color=\"red\"]" + text + "[/color]";
+	return text;
+}
+
+/**
+ * Format batch training string for the tooltip
+ * Examples:
+ * buildingsCountToTrainFullBatch = 1, fullBatchSize = 5, remainderBatch = 0:
+ * "Shift-click to train 5"
+ * buildingsCountToTrainFullBatch = 2, fullBatchSize = 5, remainderBatch = 0:
+ * "Shift-click to train 10 (2*5)"
+ * buildingsCountToTrainFullBatch = 1, fullBatchSize = 15, remainderBatch = 12:
+ * "Shift-click to train 27 (15 + 12)"
+ */
+function formatBatchTrainingString(buildingsCountToTrainFullBatch, fullBatchSize, remainderBatch)
+{
+	var totalBatchTrainingCount = buildingsCountToTrainFullBatch * fullBatchSize + remainderBatch;
+	// Don't show the batch training tooltip if either units of this type can't be trained at all
+	// or only one unit can be trained
+	if (totalBatchTrainingCount < 2)
+		return "";
+	var batchTrainingString = "";
+	var fullBatchesString = "";
+	if (buildingsCountToTrainFullBatch > 0)
+	{
+		if (buildingsCountToTrainFullBatch > 1)
+			fullBatchesString += buildingsCountToTrainFullBatch + "*";
+		fullBatchesString += fullBatchSize;
+	}
+	var remainderBatchString = remainderBatch > 0 ? remainderBatch : "";
+	var batchDetailsString = "";
+	// We need to display the batch details part if there is either more than
+	// one building with full batch or one building with the full batch and
+	// another with a partial batch
+	if (buildingsCountToTrainFullBatch > 1 ||
+		(buildingsCountToTrainFullBatch == 1 && remainderBatch > 0))
+	{
+		batchDetailsString += " (" + fullBatchesString;
+		if (remainderBatchString != "")
+			batchDetailsString += " + " + remainderBatchString;
+		batchDetailsString += ")";
+	}
+
+	return "\n\n[font=\"serif-bold-13\"]Shift-click[/font][font=\"serif-13\"] to train "
+		+ totalBatchTrainingCount + batchDetailsString + ".[/font]";
+}
+
 /**
  * Helper function for updateUnitCommands; sets up "unit panels" (i.e. panels with rows of icons) for the currently selected
  * unit.
@@ -150,7 +207,7 @@ function setOverlay(object, value)
  * @param items Panel-specific data to construct the icons with.
  * @param callback Callback function to argument to execute when an item's icon gets clicked. Takes a single 'item' argument.
  */
-function setupUnitPanel(guiName, usedPanels, unitEntState, items, callback)
+function setupUnitPanel(guiName, usedPanels, unitEntState, playerState, items, callback)
 {
 	usedPanels[guiName] = 1;
 
@@ -211,6 +268,11 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, items, callback)
 				numberOfItems = 8;
 			break;
 
+		case PACK:
+			if(numberOfItems > 8)
+				numberOfItems = 8;
+			break;
+
 		default:
 			break;
 	}
@@ -323,6 +385,9 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, items, callback)
 
 			case QUEUE:
 				var tooltip = getEntityNames(template);
+				if (item.neededSlots)
+					tooltip += "\n[color=\"red\"]Insufficient population capacity:\n[/color]"+getCostComponentDisplayName("population")+" "+item.neededSlots;
+
 				var progress = Math.round(item.progress*100) + "%";
 				getGUIObjectByName("unit"+guiName+"Count["+i+"]").caption = (item.count > 1 ? item.count : "");
 
@@ -363,6 +428,10 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, items, callback)
 				}
 				break;
 
+			case PACK:
+				var tooltip = item.tooltip;
+				break;
+
 			case STANCE:
 			case FORMATION:
 				var tooltip = toTitleCase(item);
@@ -374,10 +443,14 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, items, callback)
 				if (template.tooltip)
 					tooltip += "\n[font=\"serif-13\"]" + template.tooltip + "[/font]";
 
-				var [batchSize, batchIncrement] = getTrainingBatchStatus(unitEntState.id, entType);
-				var trainNum = batchSize ? batchSize+batchIncrement : batchIncrement;
+				var [buildingsCountToTrainFullBatch, fullBatchSize, remainderBatch] =
+					getTrainingBatchStatus(playerState, unitEntState.id, entType, selection);
+				if (Engine.HotkeyIsPressed("session.batchtrain"))
+				{
+					trainNum = buildingsCountToTrainFullBatch * fullBatchSize + remainderBatch;
+				}
 
-				tooltip += "\n" + getEntityCostTooltip(template);
+				tooltip += "\n" + getEntityCostTooltip(template, trainNum, unitEntState.id);
 
 				if (template.health)
 					tooltip += "\n[font=\"serif-bold-13\"]Health:[/font] " + template.health;
@@ -388,8 +461,16 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, items, callback)
 				if (template.speed)
 					tooltip += "\n" + getEntitySpeed(template);
 
-				tooltip += "\n\n[font=\"serif-bold-13\"]Shift-click[/font][font=\"serif-13\"] to train " + trainNum + ".[/font]";
+				var [trainEntLimit, trainEntCount, canBeTrainedCount] =
+					getEntityLimitAndCount(playerState, entType)
+				tooltip += formatLimitString(trainEntLimit, trainEntCount);
 
+				tooltip += formatBatchTrainingString(buildingsCountToTrainFullBatch, fullBatchSize, remainderBatch);
+				var key = g_ConfigDB.system["hotkey.session.queueunit." + (i+1)];
+				if (key !== undefined)
+				{
+					tooltip += "\n[font=\"serif-bold-13\"]HotKey (" + key  + ").[/font]";
+				}
 				break;
 				
 			case RESEARCH:
@@ -456,6 +537,12 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, items, callback)
 		// Items can have a callback element that overrides the normal caller-supplied callback function.
 		button.onpress = (function(e){ return function() { e.callback ? e.callback(e) : callback(e) } })(item);
 
+		if(guiName == SELECTION)
+		{
+			button.onpressright = (function(e){return function() {callback(e, true) } })(item);
+			button.onpress = (function(e){ return function() {callback(e, false) } })(item);
+		}
+
 		if (guiName == RESEARCH)
 		{
 			if (item.pair)
@@ -467,20 +554,23 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, items, callback)
 				button1.tooltip = tooltip1;
 				button1.onpress = (function(e){ return function() { callback(e) } })(item.top);
 
-				// We add a red overlay to the paired button (we reuse the selection for that)
-				button1.onmouseenter = (function(e){ return function() { setOverlay(e, true) } })(selection);
-				button1.onmouseleave = (function(e){ return function() { setOverlay(e, false) } })(selection);
+				// when we hover over a pair, the other one gets a red cross over it to show it won't be available any more.
+				var unchosenIcon = getGUIObjectByName("unit"+guiName+"UnchosenIcon["+i+"]");
+				var unchosenIcon1 = getGUIObjectByName("unit"+guiName+"UnchosenIcon["+(i+rowLength)+"]");
 
-				var selection1 = getGUIObjectByName("unit"+guiName+"Selection["+(i+rowLength)+"]");;
-				button.onmouseenter = (function(e){ return function() { setOverlay(e, true) } })(selection1);
-				button.onmouseleave = (function(e){ return function() { setOverlay(e, false) } })(selection1);
+				button1.onmouseenter = (function(e){ return function() { setOverlay(e, true) } })(unchosenIcon);
+				button1.onmouseleave = (function(e){ return function() { setOverlay(e, false) } })(unchosenIcon);
+
+				button.onmouseenter = (function(e){ return function() { setOverlay(e, true) } })(unchosenIcon1);
+				button.onmouseleave = (function(e){ return function() { setOverlay(e, false) } })(unchosenIcon1);
 
 				pair.hidden = false;
 			}
 			else
 			{
-				// Hide the overlay
-				selection.hidden = true;
+				// Hide the overlay.
+				var unchosenIcon = getGUIObjectByName("unit"+guiName+"UnchosenIcon["+i+"]");
+				unchosenIcon.hidden = true;
 			}
 		}
 
@@ -559,17 +649,36 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, items, callback)
 
 			icon.sprite = "stretched:session/" + gateIcon;
 		}
+		else if (guiName == PACK)
+		{
+			if (item.packing)
+			{
+				icon.sprite = "stretched:session/icons/cancel.png";
+			}
+			else
+			{
+				if (item.packed)
+					icon.sprite = "stretched:session/icons/unpack.png";
+				else
+					icon.sprite = "stretched:session/icons/pack.png";
+			}
+		}
 		else if (template.icon)
 		{
 			var grayscale = "";
 			button.enabled = true;
-			
-			if (guiName != SELECTION && template.requiredTechnology && !Engine.GuiInterfaceCall("IsTechnologyResearched", template.requiredTechnology))
+			if (affordableMask)
+				affordableMask.hidden = true;	// actually used for the red "lack of resource" overlay, and darkening if unavailable. Sort of a hack.
+	
+			// In case this is an icon that would require tech checking, make sure we have the requirements.
+			if (guiName != SELECTION && guiName != GARRISON && guiName != QUEUE && template.requiredTechnology && !Engine.GuiInterfaceCall("IsTechnologyResearched", template.requiredTechnology))
 			{
 				button.enabled = false;
 				var techName = getEntityNames(GetTechnologyData(template.requiredTechnology));
 				button.tooltip += "\nRequires " + techName;
 				grayscale = "grayscale:";
+                affordableMask.hidden = false;
+				affordableMask.sprite = "colour: 0 0 0 127";
 			}
 			
 			if (guiName == RESEARCH && !Engine.GuiInterfaceCall("CheckTechnologyRequirements", entType))
@@ -577,14 +686,15 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, items, callback)
 				button.enabled = false;
 				button.tooltip += "\n" + GetTechnologyData(entType).requirementsTooltip;
 				grayscale = "grayscale:";
+                affordableMask.hidden = false;
+				affordableMask.sprite = "colour: 0 0 0 127";
 			}
 			
 			icon.sprite = "stretched:" + grayscale + "session/portraits/" + template.icon;
 			
 			if (guiName == RESEARCH)
 			{
-				// Check resource requirements for first button
-				affordableMask.hidden = true;
+				// Check resource requirements
 				var neededResources = Engine.GuiInterfaceCall("GetNeededResources", template.cost);
 				if (neededResources)
 				{
@@ -592,6 +702,13 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, items, callback)
 					{
 						button.enabled = false;
 						affordableMask.hidden = false;
+						
+						var totalCost = 0;
+						for each (var resource in neededResources)
+							totalCost += resource;
+						var alpha = 50 + totalCost/10;
+						alpha = alpha > 125 ? 125 : alpha;
+						affordableMask.sprite = "colour: 255 0 0 " + (alpha);
 					}
 					button.tooltip += getNeededResourcesTooltip(neededResources);
 				}
@@ -600,24 +717,33 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, items, callback)
 				{
 					grayscale = "";
 					button1.enabled = true;
+					affordableMask1.hidden = true;
 
 					if (!Engine.GuiInterfaceCall("CheckTechnologyRequirements", entType1))
 					{
 						button1.enabled = false;
 						button1.tooltip += "\n" + GetTechnologyData(entType1).requirementsTooltip;
 						grayscale = "grayscale:";
+                        affordableMask1.hidden = false;
+						affordableMask1.sprite = "colour: 0 0 0 127";
 					}
 					icon1.sprite = "stretched:" + grayscale + "session/portraits/" +template1.icon;
 
 					// Check resource requirements for second button
-					affordableMask1.hidden = true;
-					neededResources = Engine.GuiInterfaceCall("GetNeededResources", template.cost);
+					neededResources = Engine.GuiInterfaceCall("GetNeededResources", template1.cost);
 					if (neededResources)
 					{
 						if (button1.enabled !== false)
 						{
 							button1.enabled = false;
 							affordableMask1.hidden = false;
+
+							var totalCost = 0;
+							for each (var resource in neededResources)
+								totalCost += resource;
+							var alpha = 50 + totalCost/10;
+							alpha = alpha > 125 ? 125 : alpha;
+							affordableMask1.sprite = "colour: 255 0 0 " + (alpha);
 						}
 						button1.tooltip += getNeededResourcesTooltip(neededResources);
 					}
@@ -627,37 +753,54 @@ function setupUnitPanel(guiName, usedPanels, unitEntState, items, callback)
 					pair.hidden = true;
 					button1.hidden = true;
 					affordableMask1.hidden = true;
-  				}
+				}
 			}
 			else if (guiName == CONSTRUCTION || guiName == TRAINING)
 			{
-				affordableMask.hidden = true;
 				var totalCosts = {};
 				var trainNum = 1;
-				if (Engine.HotkeyIsPressed("session.batchtrain") && guiName == TRAINING)
+				var button_disableable = true;
+				if (guiName == TRAINING)
 				{
-					var [batchSize, batchIncrement] = getTrainingBatchStatus(unitEntState.id, entType);
-					trainNum = batchSize + batchIncrement;
+					var trainingCategory = null;
+					if (template.trainingRestrictions)
+						trainingCategory = template.trainingRestrictions.category;
+					if (trainingCategory && playerState.entityLimits[trainingCategory] &&
+						playerState.entityCounts[trainingCategory] >= playerState.entityLimits[trainingCategory])
+					{
+						grayscale = "grayscale:";
+                        affordableMask.hidden = false;
+						affordableMask.sprite = "colour: 0 0 0 100";
+					}
+					icon.sprite = "stretched:" + grayscale + "session/portraits/" + template.icon;
+
+					if (Engine.HotkeyIsPressed("session.batchtrain"))
+					{
+						var [buildingsCountToTrainFullBatch, fullBatchSize, remainderBatch, batchTrainingCount] =
+							getTrainingBatchStatus(playerState, unitEntState.id, entType, selection);
+						trainNum = buildingsCountToTrainFullBatch * fullBatchSize + remainderBatch;
+						button_disableable = !Engine.HotkeyIsPressed("selection.remove");
+					}
+					getGUIObjectByName("unit"+guiName+"Count["+i+"]").caption = (batchTrainingCount > 0) ? batchTrainingCount : "";
 				}
 
 				// Walls have no cost defined.
 				if (template.cost !== undefined)
-					for (var r in template.cost)
-						totalCosts[r] = Math.floor(template.cost[r] * trainNum);
+					totalCosts = multiplyEntityCosts(template, trainNum);
 
 				var neededResources = Engine.GuiInterfaceCall("GetNeededResources", totalCosts);
 				if (neededResources)
 				{
-					var totalCost = 0;
 					if (button.enabled !== false)
 					{
+						button.enabled = (button_disableable ? false : true);
+						affordableMask.hidden = false;
+
+						var totalCost = 0;
 						for each (var resource in neededResources)
 							totalCost += resource;
-
-						button.enabled = false;
-						affordableMask.hidden = false;
-						var alpha = 75 + totalCost/6;
-						alpha = alpha > 150 ? 150 : alpha;
+						var alpha = 50 + totalCost/10;
+						alpha = alpha > 125 ? 125 : alpha;
 						affordableMask.sprite = "colour: 255 0 0 " + (alpha);
 					}
 					button.tooltip += getNeededResourcesTooltip(neededResources);
@@ -767,7 +910,7 @@ function setupUnitTradingPanel(usedPanels, unitEntState, selection)
 }
 
 // Sets up "unit barter panel" - special case for setupUnitPanel
-function setupUnitBarterPanel(unitEntState)
+function setupUnitBarterPanel(unitEntState, playerState)
 {
 	// Amount of player's resource to exchange
 	var amountToSell = BARTER_RESOURCE_AMOUNT_TO_SELL;
@@ -862,13 +1005,18 @@ function updateUnitCommands(entState, supplementalDetailsPanel, commandsPanel, s
 	var player = Engine.GetPlayerID();
 	if (entState.player == player || g_DevSettings.controlAll)
 	{
+		// Get player state to check some constraints
+		// e.g. presence of a hero or build limits
+		var simState = Engine.GuiInterfaceCall("GetSimulationState");
+		var playerState = simState.players[player];
+
 		if (selection.length > 1)
-			setupUnitPanel(SELECTION, usedPanels, entState, g_Selection.groups.getTemplateNames(),
-				function (entType) { changePrimarySelectionGroup(entType); } );
+			setupUnitPanel(SELECTION, usedPanels, entState, playerState, g_Selection.groups.getTemplateNames(),
+				function (entType, rightPressed) { changePrimarySelectionGroup(entType, rightPressed); } );
 
 		var commands = getEntityCommandsList(entState);
 		if (commands.length)
-			setupUnitPanel(COMMAND, usedPanels, entState, commands,
+			setupUnitPanel(COMMAND, usedPanels, entState, playerState, commands,
 				function (item) { performCommand(entState.id, item.name); } );
 
 		if (entState.garrisonHolder)
@@ -881,14 +1029,14 @@ function updateUnitCommands(entState, supplementalDetailsPanel, commandsPanel, s
 					groups.add(state.garrisonHolder.entities)
 			}
 
-			setupUnitPanel(GARRISON, usedPanels, entState, groups.getTemplateNames(),
+			setupUnitPanel(GARRISON, usedPanels, entState, playerState, groups.getTemplateNames(),
 				function (item) { unloadTemplate(item); } );
 		}
 
 		var formations = Engine.GuiInterfaceCall("GetAvailableFormations");
 		if (hasClass(entState, "Unit") && !hasClass(entState, "Animal") && !entState.garrisonHolder && formations.length)
 		{
-			setupUnitPanel(FORMATION, usedPanels, entState, formations,
+			setupUnitPanel(FORMATION, usedPanels, entState, playerState, formations,
 				function (item) { performFormation(entState.id, item); } );
 		}
 
@@ -897,7 +1045,7 @@ function updateUnitCommands(entState, supplementalDetailsPanel, commandsPanel, s
 		var stances = ["violent", "aggressive", "passive", "defensive", "standground"];
 		if (hasClass(entState, "Unit") && !hasClass(entState, "Animal") && stances.length)
 		{
-			setupUnitPanel(STANCE, usedPanels, entState, stances,
+			setupUnitPanel(STANCE, usedPanels, entState, playerState, stances,
 				function (item) { performStance(entState.id, item); } );
 		}
 
@@ -905,34 +1053,21 @@ function updateUnitCommands(entState, supplementalDetailsPanel, commandsPanel, s
 		if (entState.barterMarket)
 		{
 			usedPanels["Barter"] = 1;
-			setupUnitBarterPanel(entState);
+			setupUnitBarterPanel(entState, playerState);
 		}
 
-		var buildableEnts = [];
-		var trainableEnts = [];
-		var state;
-		// Get all buildable and trainable entities
-		for (var i in selection)
-		{
-			if ((state = GetEntityState(selection[i])) && state.buildEntities && state.buildEntities.length)
-				buildableEnts = buildableEnts.concat(state.buildEntities);
-			if ((state = GetEntityState(selection[i])) && state.production && state.production.entities.length)
-				trainableEnts = trainableEnts.concat(state.production.entities);
-		}
-		
-		// Remove duplicates
-		removeDupes(buildableEnts);
-		removeDupes(trainableEnts);
+		var buildableEnts = getAllBuildableEntities(selection);
+		var trainableEnts = getAllTrainableEntities(selection);
 
 		// Whether the GUI's right panel has been filled.
 		var rightUsed = true;
 
 		// The first selected entity's type has priority.
 		if (entState.buildEntities)
-			setupUnitPanel(CONSTRUCTION, usedPanels, entState, buildableEnts, startBuildingPlacement);
+			setupUnitPanel(CONSTRUCTION, usedPanels, entState, playerState, buildableEnts, startBuildingPlacement);
 		else if (entState.production && entState.production.entities)
-			setupUnitPanel(TRAINING, usedPanels, entState, trainableEnts,
-				function (trainEntType) { addTrainingToQueue(selection, trainEntType); } );
+			setupUnitPanel(TRAINING, usedPanels, entState, playerState, trainableEnts,
+				function (trainEntType) { addTrainingToQueue(selection, trainEntType, playerState); } );
 		else if (entState.trader)
 			setupUnitTradingPanel(usedPanels, entState, selection);
 		else if (!entState.foundation && entState.gate || hasClass(entState, "LongWall"))
@@ -979,7 +1114,51 @@ function updateUnitCommands(entState, supplementalDetailsPanel, commandsPanel, s
 			// Place wall conversion options after gate lock/unlock icons.
 			var items = gates.concat(walls);
 			if (items.length)
-				setupUnitPanel(GATE, usedPanels, entState, items);
+				setupUnitPanel(GATE, usedPanels, entState, playerState, items);
+			else
+				rightUsed = false;
+		}
+		else if (entState.pack)
+		{
+			var items = [];
+			var packButton = false;
+			var unpackButton = false;
+			var packCancelButton = false;
+			var unpackCancelButton = false;
+			for (var i in selection)
+			{
+				// Find un/packable entities
+				var state = GetEntityState(selection[i]);
+				if (state.pack)
+				{
+					if (state.pack.progress == 0)
+					{
+						if (!state.pack.packed)
+							packButton = true;
+						else if (state.pack.packed)
+							unpackButton = true;
+					}
+					else
+					{
+						// Already un/packing - show cancel button
+						if (!state.pack.packed)
+							packCancelButton = true;
+						else if (state.pack.packed)
+							unpackCancelButton = true;
+					}
+				}
+			}
+			if (packButton)
+				items.push({ "packing": false, "packed": false, "tooltip": "Pack", "callback": function() { packUnit(true); } });
+			if (unpackButton)
+				items.push({ "packing": false, "packed": true, "tooltip": "Unpack", "callback": function() { packUnit(false); } });
+			if (packCancelButton)
+				items.push({ "packing": true, "packed": false, "tooltip": "Cancel packing", "callback": function() { cancelPackUnit(true); } });
+			if (unpackCancelButton)
+				items.push({ "packing": true, "packed": true, "tooltip": "Cancel unpacking", "callback": function() { cancelPackUnit(false); } });
+
+			if (items.length)
+				setupUnitPanel(PACK, usedPanels, entState, playerState, items);
 			else
 				rightUsed = false;
 		}
@@ -991,23 +1170,22 @@ function updateUnitCommands(entState, supplementalDetailsPanel, commandsPanel, s
 			// The right pane is empty. Fill the pane with a sane type.
 			// Prefer buildables for units and trainables for structures.
 			if (buildableEnts.length && (hasClass(entState, "Unit") || !trainableEnts.length))
-				setupUnitPanel(CONSTRUCTION, usedPanels, entState, buildableEnts, startBuildingPlacement);
+				setupUnitPanel(CONSTRUCTION, usedPanels, entState, playerState, buildableEnts, startBuildingPlacement);
 			else if (trainableEnts.length)
-				setupUnitPanel(TRAINING, usedPanels, entState, trainableEnts,
-					function (trainEntType) { addTrainingToQueue(selection, trainEntType); } );
+				setupUnitPanel(TRAINING, usedPanels, entState, playerState, trainableEnts,
+					function (trainEntType) { addTrainingToQueue(selection, trainEntType, playerState); } );
 		}
-
 		// Show technologies if the active panel has at most one row of icons.
 		if (entState.production && entState.production.technologies.length)
 		{
 			var activepane = usedPanels[CONSTRUCTION] ? buildableEnts.length : trainableEnts.length;
 			if (selection.length == 1 || activepane <= 8)
-				setupUnitPanel(RESEARCH, usedPanels, entState, entState.production.technologies,
+				setupUnitPanel(RESEARCH, usedPanels, entState, playerState, entState.production.technologies,
 					function (researchType) { addResearchToQueue(entState.id, researchType); } );
 		}
 
 		if (entState.production && entState.production.queue.length)
-			setupUnitPanel(QUEUE, usedPanels, entState, entState.production.queue,
+			setupUnitPanel(QUEUE, usedPanels, entState, playerState, entState.production.queue,
 				function (item) { removeFromProductionQueue(entState.id, item.id); } );
 		
 		supplementalDetailsPanel.hidden = false;
@@ -1037,3 +1215,37 @@ function hideUnitCommands()
 	for each (var panelName in g_unitPanels)
 		getGUIObjectByName("unit" + panelName + "Panel").hidden = true;
 }
+
+// Get all of the available entities which can be trained by the selected entities
+function getAllTrainableEntities(selection)
+{
+	var trainableEnts = [];
+	var state;
+	// Get all buildable and trainable entities
+	for (var i in selection)
+	{
+		if ((state = GetEntityState(selection[i])) && state.production && state.production.entities.length)
+			trainableEnts = trainableEnts.concat(state.production.entities);
+	}
+	
+	// Remove duplicates
+	removeDupes(trainableEnts);
+	return trainableEnts;
+}
+
+// Get all of the available entities which can be built by the selected entities
+function getAllBuildableEntities(selection)
+{
+	var buildableEnts = [];
+	var state;
+	// Get all buildable entities
+	for (var i in selection)
+	{
+		if ((state = GetEntityState(selection[i])) && state.buildEntities && state.buildEntities.length)
+			buildableEnts = buildableEnts.concat(state.buildEntities);
+	}
+	
+	// Remove duplicates
+	removeDupes(buildableEnts);
+	return buildableEnts;
+}
